# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/pfs/pfs.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from python_pachyderm.proto.auth import auth_pb2 as client_dot_auth_dot_auth__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/pfs/pfs.proto',
  package='pfs',
  syntax='proto3',
  serialized_options=b'Z-github.com/pachyderm/pachyderm/src/client/pfs',
  serialized_pb=b'\n\x14\x63lient/pfs/pfs.proto\x12\x03pfs\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16\x63lient/auth/auth.proto\"\x14\n\x04Repo\x12\x0c\n\x04name\x18\x01 \x01(\t\"/\n\x06\x42ranch\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\x12\x0c\n\x04name\x18\x02 \x01(\t\"1\n\x04\x46ile\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x15\n\x05\x42lock\x12\x0c\n\x04hash\x18\x01 \x01(\t\"\x16\n\x06Object\x12\x0c\n\x04hash\x18\x01 \x01(\t\"\x13\n\x03Tag\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xd7\x01\n\x08RepoInfo\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsize_bytes\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x1d\n\x08\x62ranches\x18\x07 \x03(\x0b\x32\x0b.pfs.Branch\x12$\n\tauth_info\x18\x06 \x01(\x0b\x32\x11.pfs.RepoAuthInfo\x12\x11\n\ttombstone\x18\x08 \x01(\x08J\x04\x08\x04\x10\x05\"1\n\x0cRepoAuthInfo\x12!\n\x0c\x61\x63\x63\x65ss_level\x18\x01 \x01(\x0e\x32\x0b.auth.Scope\"\xdb\x01\n\nBranchInfo\x12\x1b\n\x06\x62ranch\x18\x04 \x01(\x0b\x32\x0b.pfs.Branch\x12\x19\n\x04head\x18\x02 \x01(\x0b\x32\x0b.pfs.Commit\x12\x1f\n\nprovenance\x18\x03 \x03(\x0b\x32\x0b.pfs.Branch\x12\x1f\n\nsubvenance\x18\x05 \x03(\x0b\x32\x0b.pfs.Branch\x12&\n\x11\x64irect_provenance\x18\x06 \x03(\x0b\x32\x0b.pfs.Branch\x12\x1d\n\x07trigger\x18\x07 \x01(\x0b\x32\x0c.pfs.Trigger\x12\x0c\n\x04name\x18\x01 \x01(\t\"3\n\x0b\x42ranchInfos\x12$\n\x0b\x62ranch_info\x18\x01 \x03(\x0b\x32\x0f.pfs.BranchInfo\"X\n\x07Trigger\x12\x0e\n\x06\x62ranch\x18\x01 \x01(\t\x12\x0b\n\x03\x61ll\x18\x02 \x01(\x08\x12\x11\n\tcron_spec\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\x0f\n\x07\x63ommits\x18\x05 \x01(\x03\"-\n\x0c\x43ommitOrigin\x12\x1d\n\x04kind\x18\x01 \x01(\x0e\x32\x0f.pfs.OriginKind\"-\n\x06\x43ommit\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\x12\n\n\x02id\x18\x02 \x01(\t\"E\n\x0b\x43ommitRange\x12\x1a\n\x05lower\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x1a\n\x05upper\x18\x02 \x01(\x0b\x32\x0b.pfs.Commit\"L\n\x10\x43ommitProvenance\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x1b\n\x06\x62ranch\x18\x02 \x01(\x0b\x32\x0b.pfs.Branch\"\xe7\x04\n\nCommitInfo\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x1b\n\x06\x62ranch\x18\x0f \x01(\x0b\x32\x0b.pfs.Branch\x12!\n\x06origin\x18\x11 \x01(\x0b\x32\x11.pfs.CommitOrigin\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\"\n\rparent_commit\x18\x02 \x01(\x0b\x32\x0b.pfs.Commit\x12\"\n\rchild_commits\x18\x0b \x03(\x0b\x32\x0b.pfs.Commit\x12+\n\x07started\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x66inished\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsize_bytes\x18\x05 \x01(\x04\x12)\n\nprovenance\x18\x10 \x03(\x0b\x32\x15.pfs.CommitProvenance\x12\x18\n\x10ready_provenance\x18\x0c \x01(\x03\x12$\n\nsubvenance\x18\t \x03(\x0b\x32\x10.pfs.CommitRange\x12\x19\n\x04tree\x18\x07 \x01(\x0b\x32\x0b.pfs.Object\x12\x1a\n\x05trees\x18\r \x03(\x0b\x32\x0b.pfs.Object\x12\x1b\n\x06\x64\x61tums\x18\x0e \x01(\x0b\x32\x0b.pfs.Object\x12!\n\x19subvenant_commits_success\x18\x12 \x01(\x03\x12!\n\x19subvenant_commits_failure\x18\x13 \x01(\x03\x12\x1f\n\x17subvenant_commits_total\x18\x14 \x01(\x03J\x04\x08\x06\x10\x07J\x04\x08\n\x10\x0b\"\xe8\x01\n\x08\x46ileInfo\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.pfs.File\x12 \n\tfile_type\x18\x02 \x01(\x0e\x32\r.pfs.FileType\x12\x12\n\nsize_bytes\x18\x03 \x01(\x04\x12-\n\tcommitted\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x63hildren\x18\x06 \x03(\t\x12\x1c\n\x07objects\x18\x08 \x03(\x0b\x32\x0b.pfs.Object\x12 \n\tblockRefs\x18\t \x03(\x0b\x32\r.pfs.BlockRef\x12\x0c\n\x04hash\x18\x07 \x01(\x0c\")\n\tByteRange\x12\r\n\x05lower\x18\x01 \x01(\x04\x12\r\n\x05upper\x18\x02 \x01(\x04\"D\n\x08\x42lockRef\x12\x19\n\x05\x62lock\x18\x01 \x01(\x0b\x32\n.pfs.Block\x12\x1d\n\x05range\x18\x02 \x01(\x0b\x32\x0e.pfs.ByteRange\"K\n\nObjectInfo\x12\x1b\n\x06object\x18\x01 \x01(\x0b\x32\x0b.pfs.Object\x12 \n\tblock_ref\x18\x02 \x01(\x0b\x32\r.pfs.BlockRef\"$\n\nCompaction\x12\x16\n\x0einput_prefixes\x18\x02 \x03(\t\"`\n\x05Shard\x12#\n\ncompaction\x18\x01 \x01(\x0b\x32\x0f.pfs.Compaction\x12\x1d\n\x05range\x18\x02 \x01(\x0b\x32\x0e.pfs.PathRange\x12\x13\n\x0boutput_path\x18\x03 \x01(\t\")\n\tPathRange\x12\r\n\x05lower\x18\x01 \x01(\t\x12\r\n\x05upper\x18\x02 \x01(\t\"W\n\x11\x43reateRepoRequest\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\x08J\x04\x08\x02\x10\x03\"-\n\x12InspectRepoRequest\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\"\x17\n\x0fListRepoRequestJ\x04\x08\x01\x10\x02\"4\n\x10ListRepoResponse\x12 \n\trepo_info\x18\x01 \x03(\x0b\x32\r.pfs.RepoInfo\"c\n\x11\x44\x65leteRepoRequest\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\x12\x0b\n\x03\x61ll\x18\x03 \x01(\x08\x12\x19\n\x11split_transaction\x18\x04 \x01(\x08\"\x87\x01\n\x12StartCommitRequest\x12\x1b\n\x06parent\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12)\n\nprovenance\x18\x05 \x03(\x0b\x32\x15.pfs.CommitProvenanceJ\x04\x08\x02\x10\x03\"\xe4\x02\n\x12\x42uildCommitRequest\x12\x1b\n\x06parent\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x0e\n\x06\x62ranch\x18\x04 \x01(\t\x12!\n\x06origin\x18\x0c \x01(\x0b\x32\x11.pfs.CommitOrigin\x12)\n\nprovenance\x18\x06 \x03(\x0b\x32\x15.pfs.CommitProvenance\x12\x19\n\x04tree\x18\x03 \x01(\x0b\x32\x0b.pfs.Object\x12\x1a\n\x05trees\x18\x07 \x03(\x0b\x32\x0b.pfs.Object\x12\x1b\n\x06\x64\x61tums\x18\x08 \x01(\x0b\x32\x0b.pfs.Object\x12\n\n\x02ID\x18\x05 \x01(\t\x12\x12\n\nsize_bytes\x18\t \x01(\x04\x12+\n\x07started\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x66inished\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x02\x10\x03\"\xbe\x01\n\x13\x46inishCommitRequest\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x19\n\x04tree\x18\x03 \x01(\x0b\x32\x0b.pfs.Object\x12\x1a\n\x05trees\x18\x05 \x03(\x0b\x32\x0b.pfs.Object\x12\x1b\n\x06\x64\x61tums\x18\x07 \x01(\x0b\x32\x0b.pfs.Object\x12\x12\n\nsize_bytes\x18\x06 \x01(\x04\x12\r\n\x05\x65mpty\x18\x04 \x01(\x08\"Z\n\x14InspectCommitRequest\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12%\n\x0b\x62lock_state\x18\x02 \x01(\x0e\x32\x10.pfs.CommitState\"\x81\x01\n\x11ListCommitRequest\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\x12\x19\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x0b.pfs.Commit\x12\x17\n\x02to\x18\x03 \x01(\x0b\x32\x0b.pfs.Commit\x12\x0e\n\x06number\x18\x04 \x01(\x04\x12\x0f\n\x07reverse\x18\x05 \x01(\x08\"3\n\x0b\x43ommitInfos\x12$\n\x0b\x63ommit_info\x18\x01 \x03(\x0b\x32\x0f.pfs.CommitInfo\"\x9f\x01\n\x13\x43reateBranchRequest\x12\x19\n\x04head\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x10\n\x08s_branch\x18\x02 \x01(\t\x12\x1b\n\x06\x62ranch\x18\x03 \x01(\x0b\x32\x0b.pfs.Branch\x12\x1f\n\nprovenance\x18\x04 \x03(\x0b\x32\x0b.pfs.Branch\x12\x1d\n\x07trigger\x18\x05 \x01(\x0b\x32\x0c.pfs.Trigger\"3\n\x14InspectBranchRequest\x12\x1b\n\x06\x62ranch\x18\x01 \x01(\x0b\x32\x0b.pfs.Branch\"=\n\x11ListBranchRequest\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\x12\x0f\n\x07reverse\x18\x02 \x01(\x08\"A\n\x13\x44\x65leteBranchRequest\x12\x1b\n\x06\x62ranch\x18\x01 \x01(\x0b\x32\x0b.pfs.Branch\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"2\n\x13\x44\x65leteCommitRequest\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\"O\n\x12\x46lushCommitRequest\x12\x1c\n\x07\x63ommits\x18\x01 \x03(\x0b\x32\x0b.pfs.Commit\x12\x1b\n\x08to_repos\x18\x02 \x03(\x0b\x32\t.pfs.Repo\"\xa2\x01\n\x16SubscribeCommitRequest\x12\x17\n\x04repo\x18\x01 \x01(\x0b\x32\t.pfs.Repo\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12#\n\x04prov\x18\x05 \x01(\x0b\x32\x15.pfs.CommitProvenance\x12\x19\n\x04\x66rom\x18\x03 \x01(\x0b\x32\x0b.pfs.Commit\x12\x1f\n\x05state\x18\x04 \x01(\x0e\x32\x10.pfs.CommitState\"S\n\x0eGetFileRequest\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.pfs.File\x12\x14\n\x0coffset_bytes\x18\x02 \x01(\x03\x12\x12\n\nsize_bytes\x18\x03 \x01(\x03\"\x1f\n\x0eOverwriteIndex\x12\r\n\x05index\x18\x01 \x01(\x03\"\x94\x02\n\x0ePutFileRequest\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.pfs.File\x12\r\n\x05value\x18\x03 \x01(\x0c\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x11\n\trecursive\x18\x06 \x01(\x08\x12!\n\tdelimiter\x18\x07 \x01(\x0e\x32\x0e.pfs.Delimiter\x12\x1a\n\x12target_file_datums\x18\x08 \x01(\x03\x12\x19\n\x11target_file_bytes\x18\t \x01(\x03\x12\x16\n\x0eheader_records\x18\x0b \x01(\x03\x12,\n\x0foverwrite_index\x18\n \x01(\x0b\x32\x13.pfs.OverwriteIndex\x12\x0e\n\x06\x64\x65lete\x18\x0c \x01(\x08J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05\"\x88\x01\n\rPutFileRecord\x12\x12\n\nsize_bytes\x18\x01 \x01(\x03\x12\x13\n\x0bobject_hash\x18\x02 \x01(\t\x12,\n\x0foverwrite_index\x18\x03 \x01(\x0b\x32\x13.pfs.OverwriteIndex\x12 \n\tblock_ref\x18\x04 \x01(\x0b\x32\r.pfs.BlockRef\"\x9f\x01\n\x0ePutFileRecords\x12\r\n\x05split\x18\x01 \x01(\x08\x12#\n\x07records\x18\x02 \x03(\x0b\x32\x12.pfs.PutFileRecord\x12\x11\n\ttombstone\x18\x03 \x01(\x08\x12\"\n\x06header\x18\x04 \x01(\x0b\x32\x12.pfs.PutFileRecord\x12\"\n\x06\x66ooter\x18\x05 \x01(\x0b\x32\x12.pfs.PutFileRecord\"T\n\x0f\x43opyFileRequest\x12\x16\n\x03src\x18\x01 \x01(\x0b\x32\t.pfs.File\x12\x16\n\x03\x64st\x18\x02 \x01(\x0b\x32\t.pfs.File\x12\x11\n\toverwrite\x18\x03 \x01(\x08\"-\n\x12InspectFileRequest\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.pfs.File\"I\n\x0fListFileRequest\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.pfs.File\x12\x0c\n\x04\x66ull\x18\x02 \x01(\x08\x12\x0f\n\x07history\x18\x03 \x01(\x03\"*\n\x0fWalkFileRequest\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.pfs.File\"?\n\x0fGlobFileRequest\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"-\n\tFileInfos\x12 \n\tfile_info\x18\x01 \x03(\x0b\x32\r.pfs.FileInfo\"\\\n\x0f\x44iffFileRequest\x12\x1b\n\x08new_file\x18\x01 \x01(\x0b\x32\t.pfs.File\x12\x1b\n\x08old_file\x18\x02 \x01(\x0b\x32\t.pfs.File\x12\x0f\n\x07shallow\x18\x03 \x01(\x08\"V\n\x10\x44iffFileResponse\x12 \n\tnew_files\x18\x01 \x03(\x0b\x32\r.pfs.FileInfo\x12 \n\told_files\x18\x02 \x03(\x0b\x32\r.pfs.FileInfo\",\n\x11\x44\x65leteFileRequest\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.pfs.File\"\x1a\n\x0b\x46sckRequest\x12\x0b\n\x03\x66ix\x18\x01 \x01(\x08\"*\n\x0c\x46sckResponse\x12\x0b\n\x03\x66ix\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\x9e\x01\n\x16\x46ileOperationRequestV2\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\x12\'\n\x07put_tar\x18\x02 \x01(\x0b\x32\x14.pfs.PutTarRequestV2H\x00\x12\x31\n\x0c\x64\x65lete_files\x18\x03 \x01(\x0b\x32\x19.pfs.DeleteFilesRequestV2H\x00\x42\x0b\n\toperation\"?\n\x0fPutTarRequestV2\x12\x11\n\toverwrite\x18\x01 \x01(\x08\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"2\n\x14\x44\x65leteFilesRequestV2\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"*\n\x0fGetTarRequestV2\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.pfs.File\"V\n\x12\x44iffFileResponseV2\x12\x1f\n\x08old_file\x18\x01 \x01(\x0b\x32\r.pfs.FileInfo\x12\x1f\n\x08new_file\x18\x02 \x01(\x0b\x32\r.pfs.FileInfo\".\n\x18\x43reateTmpFileSetResponse\x12\x12\n\nfileset_id\x18\x01 \x01(\t\"A\n\x16RenewTmpFileSetRequest\x12\x12\n\nfileset_id\x18\x01 \x01(\t\x12\x13\n\x0bttl_seconds\x18\x02 \x01(\x03\"3\n\x14\x43learCommitRequestV2\x12\x1b\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0b.pfs.Commit\"T\n\x10PutObjectRequest\x12\r\n\x05value\x18\x01 \x01(\x0c\x12\x16\n\x04tags\x18\x02 \x03(\x0b\x32\x08.pfs.Tag\x12\x19\n\x05\x62lock\x18\x03 \x01(\x0b\x32\n.pfs.Block\"T\n\x13\x43reateObjectRequest\x12\x1b\n\x06object\x18\x01 \x01(\x0b\x32\x0b.pfs.Object\x12 \n\tblock_ref\x18\x02 \x01(\x0b\x32\r.pfs.BlockRef\"o\n\x11GetObjectsRequest\x12\x1c\n\x07objects\x18\x01 \x03(\x0b\x32\x0b.pfs.Object\x12\x14\n\x0coffset_bytes\x18\x02 \x01(\x04\x12\x12\n\nsize_bytes\x18\x03 \x01(\x04\x12\x12\n\ntotal_size\x18\x04 \x01(\x04\";\n\x0fPutBlockRequest\x12\x19\n\x05\x62lock\x18\x01 \x01(\x0b\x32\n.pfs.Block\x12\r\n\x05value\x18\x02 \x01(\x0c\",\n\x0fGetBlockRequest\x12\x19\n\x05\x62lock\x18\x01 \x01(\x0b\x32\n.pfs.Block\"r\n\x10GetBlocksRequest\x12 \n\tblockRefs\x18\x01 \x03(\x0b\x32\r.pfs.BlockRef\x12\x14\n\x0coffset_bytes\x18\x02 \x01(\x04\x12\x12\n\nsize_bytes\x18\x03 \x01(\x04\x12\x12\n\ntotal_size\x18\x04 \x01(\x04\"\x12\n\x10ListBlockRequest\"G\n\x10TagObjectRequest\x12\x1b\n\x06object\x18\x01 \x01(\x0b\x32\x0b.pfs.Object\x12\x16\n\x04tags\x18\x02 \x03(\x0b\x32\x08.pfs.Tag\"\x14\n\x12ListObjectsRequest\"9\n\x0fListTagsRequest\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x16\n\x0einclude_object\x18\x02 \x01(\x08\"F\n\x10ListTagsResponse\x12\x15\n\x03tag\x18\x01 \x01(\x0b\x32\x08.pfs.Tag\x12\x1b\n\x06object\x18\x02 \x01(\x0b\x32\x0b.pfs.Object\"4\n\x14\x44\x65leteObjectsRequest\x12\x1c\n\x07objects\x18\x01 \x03(\x0b\x32\x0b.pfs.Object\"\x17\n\x15\x44\x65leteObjectsResponse\"+\n\x11\x44\x65leteTagsRequest\x12\x16\n\x04tags\x18\x01 \x03(\x0b\x32\x08.pfs.Tag\"\x14\n\x12\x44\x65leteTagsResponse\"1\n\x12\x43heckObjectRequest\x12\x1b\n\x06object\x18\x01 \x01(\x0b\x32\x0b.pfs.Object\"%\n\x13\x43heckObjectResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\"\'\n\x07Objects\x12\x1c\n\x07objects\x18\x01 \x03(\x0b\x32\x0b.pfs.Object\"1\n\x13PutObjDirectRequest\x12\x0b\n\x03obj\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"\"\n\x13GetObjDirectRequest\x12\x0b\n\x03obj\x18\x01 \x01(\t\"8\n\x16\x44\x65leteObjDirectRequest\x12\x0e\n\x06object\x18\x01 \x01(\t\x12\x0e\n\x06prefix\x18\x02 \x01(\t\"\xe0\x01\n\x0bObjectIndex\x12.\n\x07objects\x18\x01 \x03(\x0b\x32\x1d.pfs.ObjectIndex.ObjectsEntry\x12(\n\x04tags\x18\x02 \x03(\x0b\x32\x1a.pfs.ObjectIndex.TagsEntry\x1a=\n\x0cObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1c\n\x05value\x18\x02 \x01(\x0b\x32\r.pfs.BlockRef:\x02\x38\x01\x1a\x38\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1a\n\x05value\x18\x02 \x01(\x0b\x32\x0b.pfs.Object:\x02\x38\x01**\n\nOriginKind\x12\x08\n\x04USER\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\x08\n\x04\x46SCK\x10\x02*+\n\x08\x46ileType\x12\x0c\n\x08RESERVED\x10\x00\x12\x08\n\x04\x46ILE\x10\x01\x12\x07\n\x03\x44IR\x10\x02*3\n\x0b\x43ommitState\x12\x0b\n\x07STARTED\x10\x00\x12\t\n\x05READY\x10\x01\x12\x0c\n\x08\x46INISHED\x10\x02*;\n\tDelimiter\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04JSON\x10\x01\x12\x08\n\x04LINE\x10\x02\x12\x07\n\x03SQL\x10\x03\x12\x07\n\x03\x43SV\x10\x04\x32\xd0\x11\n\x03\x41PI\x12>\n\nCreateRepo\x12\x16.pfs.CreateRepoRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x37\n\x0bInspectRepo\x12\x17.pfs.InspectRepoRequest\x1a\r.pfs.RepoInfo\"\x00\x12\x39\n\x08ListRepo\x12\x14.pfs.ListRepoRequest\x1a\x15.pfs.ListRepoResponse\"\x00\x12>\n\nDeleteRepo\x12\x16.pfs.DeleteRepoRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x35\n\x0bStartCommit\x12\x17.pfs.StartCommitRequest\x1a\x0b.pfs.Commit\"\x00\x12\x42\n\x0c\x46inishCommit\x12\x18.pfs.FinishCommitRequest\x1a\x16.google.protobuf.Empty\"\x00\x12=\n\rInspectCommit\x12\x19.pfs.InspectCommitRequest\x1a\x0f.pfs.CommitInfo\"\x00\x12\x38\n\nListCommit\x12\x16.pfs.ListCommitRequest\x1a\x10.pfs.CommitInfos\"\x00\x12?\n\x10ListCommitStream\x12\x16.pfs.ListCommitRequest\x1a\x0f.pfs.CommitInfo\"\x00\x30\x01\x12\x42\n\x0c\x44\x65leteCommit\x12\x18.pfs.DeleteCommitRequest\x1a\x16.google.protobuf.Empty\"\x00\x12;\n\x0b\x46lushCommit\x12\x17.pfs.FlushCommitRequest\x1a\x0f.pfs.CommitInfo\"\x00\x30\x01\x12\x43\n\x0fSubscribeCommit\x12\x1b.pfs.SubscribeCommitRequest\x1a\x0f.pfs.CommitInfo\"\x00\x30\x01\x12\x35\n\x0b\x42uildCommit\x12\x17.pfs.BuildCommitRequest\x1a\x0b.pfs.Commit\"\x00\x12\x42\n\x0c\x43reateBranch\x12\x18.pfs.CreateBranchRequest\x1a\x16.google.protobuf.Empty\"\x00\x12=\n\rInspectBranch\x12\x19.pfs.InspectBranchRequest\x1a\x0f.pfs.BranchInfo\"\x00\x12\x38\n\nListBranch\x12\x16.pfs.ListBranchRequest\x1a\x10.pfs.BranchInfos\"\x00\x12\x42\n\x0c\x44\x65leteBranch\x12\x18.pfs.DeleteBranchRequest\x1a\x16.google.protobuf.Empty\"\x00\x12:\n\x07PutFile\x12\x13.pfs.PutFileRequest\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12:\n\x08\x43opyFile\x12\x14.pfs.CopyFileRequest\x1a\x16.google.protobuf.Empty\"\x00\x12?\n\x07GetFile\x12\x13.pfs.GetFileRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12\x37\n\x0bInspectFile\x12\x17.pfs.InspectFileRequest\x1a\r.pfs.FileInfo\"\x00\x12\x32\n\x08ListFile\x12\x14.pfs.ListFileRequest\x1a\x0e.pfs.FileInfos\"\x00\x12\x39\n\x0eListFileStream\x12\x14.pfs.ListFileRequest\x1a\r.pfs.FileInfo\"\x00\x30\x01\x12\x33\n\x08WalkFile\x12\x14.pfs.WalkFileRequest\x1a\r.pfs.FileInfo\"\x00\x30\x01\x12\x32\n\x08GlobFile\x12\x14.pfs.GlobFileRequest\x1a\x0e.pfs.FileInfos\"\x00\x12\x39\n\x0eGlobFileStream\x12\x14.pfs.GlobFileRequest\x1a\r.pfs.FileInfo\"\x00\x30\x01\x12\x39\n\x08\x44iffFile\x12\x14.pfs.DiffFileRequest\x1a\x15.pfs.DiffFileResponse\"\x00\x12>\n\nDeleteFile\x12\x16.pfs.DeleteFileRequest\x1a\x16.google.protobuf.Empty\"\x00\x12=\n\tDeleteAll\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12/\n\x04\x46sck\x12\x10.pfs.FsckRequest\x1a\x11.pfs.FsckResponse\"\x00\x30\x01\x12J\n\x0f\x46ileOperationV2\x12\x1b.pfs.FileOperationRequestV2\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12\x41\n\x08GetTarV2\x12\x14.pfs.GetTarRequestV2\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12?\n\nDiffFileV2\x12\x14.pfs.DiffFileRequest\x1a\x17.pfs.DiffFileResponseV2\"\x00\x30\x01\x12R\n\x10\x43reateTmpFileSet\x12\x1b.pfs.FileOperationRequestV2\x1a\x1d.pfs.CreateTmpFileSetResponse\"\x00(\x01\x12H\n\x0fRenewTmpFileSet\x12\x1b.pfs.RenewTmpFileSetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x44\n\rClearCommitV2\x12\x19.pfs.ClearCommitRequestV2\x1a\x16.google.protobuf.Empty\"\x00\x32\xac\x0b\n\tObjectAPI\x12\x33\n\tPutObject\x12\x15.pfs.PutObjectRequest\x1a\x0b.pfs.Object\"\x00(\x01\x12\x39\n\x0ePutObjectSplit\x12\x15.pfs.PutObjectRequest\x1a\x0c.pfs.Objects\"\x00(\x01\x12?\n\nPutObjects\x12\x15.pfs.PutObjectRequest\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12\x42\n\x0c\x43reateObject\x12\x18.pfs.CreateObjectRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x39\n\tGetObject\x12\x0b.pfs.Object\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12\x45\n\nGetObjects\x12\x16.pfs.GetObjectsRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12<\n\x08PutBlock\x12\x14.pfs.PutBlockRequest\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12\x41\n\x08GetBlock\x12\x14.pfs.GetBlockRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12\x43\n\tGetBlocks\x12\x15.pfs.GetBlocksRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12\x32\n\tListBlock\x12\x15.pfs.ListBlockRequest\x1a\n.pfs.Block\"\x00\x30\x01\x12<\n\tTagObject\x12\x15.pfs.TagObjectRequest\x1a\x16.google.protobuf.Empty\"\x00\x12/\n\rInspectObject\x12\x0b.pfs.Object\x1a\x0f.pfs.ObjectInfo\"\x00\x12\x42\n\x0b\x43heckObject\x12\x17.pfs.CheckObjectRequest\x1a\x18.pfs.CheckObjectResponse\"\x00\x12;\n\x0bListObjects\x12\x17.pfs.ListObjectsRequest\x1a\x0f.pfs.ObjectInfo\"\x00\x30\x01\x12H\n\rDeleteObjects\x12\x19.pfs.DeleteObjectsRequest\x1a\x1a.pfs.DeleteObjectsResponse\"\x00\x12\x33\n\x06GetTag\x12\x08.pfs.Tag\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12)\n\nInspectTag\x12\x08.pfs.Tag\x1a\x0f.pfs.ObjectInfo\"\x00\x12;\n\x08ListTags\x12\x14.pfs.ListTagsRequest\x1a\x15.pfs.ListTagsResponse\"\x00\x30\x01\x12?\n\nDeleteTags\x12\x16.pfs.DeleteTagsRequest\x1a\x17.pfs.DeleteTagsResponse\"\x00\x12;\n\x07\x43ompact\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12\x44\n\x0cPutObjDirect\x12\x18.pfs.PutObjDirectRequest\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12I\n\x0cGetObjDirect\x12\x18.pfs.GetObjDirectRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12H\n\x0f\x44\x65leteObjDirect\x12\x1b.pfs.DeleteObjDirectRequest\x1a\x16.google.protobuf.Empty\"\x00\x42/Z-github.com/pachyderm/pachyderm/src/client/pfsb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,client_dot_auth_dot_auth__pb2.DESCRIPTOR,])

_ORIGINKIND = _descriptor.EnumDescriptor(
  name='OriginKind',
  full_name='pfs.OriginKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FSCK', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7705,
  serialized_end=7747,
)
_sym_db.RegisterEnumDescriptor(_ORIGINKIND)

OriginKind = enum_type_wrapper.EnumTypeWrapper(_ORIGINKIND)
_FILETYPE = _descriptor.EnumDescriptor(
  name='FileType',
  full_name='pfs.FileType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7749,
  serialized_end=7792,
)
_sym_db.RegisterEnumDescriptor(_FILETYPE)

FileType = enum_type_wrapper.EnumTypeWrapper(_FILETYPE)
_COMMITSTATE = _descriptor.EnumDescriptor(
  name='CommitState',
  full_name='pfs.CommitState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7794,
  serialized_end=7845,
)
_sym_db.RegisterEnumDescriptor(_COMMITSTATE)

CommitState = enum_type_wrapper.EnumTypeWrapper(_COMMITSTATE)
_DELIMITER = _descriptor.EnumDescriptor(
  name='Delimiter',
  full_name='pfs.Delimiter',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SQL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CSV', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7847,
  serialized_end=7906,
)
_sym_db.RegisterEnumDescriptor(_DELIMITER)

Delimiter = enum_type_wrapper.EnumTypeWrapper(_DELIMITER)
USER = 0
AUTO = 1
FSCK = 2
RESERVED = 0
FILE = 1
DIR = 2
STARTED = 0
READY = 1
FINISHED = 2
NONE = 0
JSON = 1
LINE = 2
SQL = 3
CSV = 4



_REPO = _descriptor.Descriptor(
  name='Repo',
  full_name='pfs.Repo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pfs.Repo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=167,
)


_BRANCH = _descriptor.Descriptor(
  name='Branch',
  full_name='pfs.Branch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.Branch.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='pfs.Branch.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=216,
)


_FILE = _descriptor.Descriptor(
  name='File',
  full_name='pfs.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.File.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='pfs.File.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=267,
)


_BLOCK = _descriptor.Descriptor(
  name='Block',
  full_name='pfs.Block',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='pfs.Block.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=290,
)


_OBJECT = _descriptor.Descriptor(
  name='Object',
  full_name='pfs.Object',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='pfs.Object.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=314,
)


_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='pfs.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pfs.Tag.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=335,
)


_REPOINFO = _descriptor.Descriptor(
  name='RepoInfo',
  full_name='pfs.RepoInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.RepoInfo.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created', full_name='pfs.RepoInfo.created', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.RepoInfo.size_bytes', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs.RepoInfo.description', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branches', full_name='pfs.RepoInfo.branches', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_info', full_name='pfs.RepoInfo.auth_info', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tombstone', full_name='pfs.RepoInfo.tombstone', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=553,
)


_REPOAUTHINFO = _descriptor.Descriptor(
  name='RepoAuthInfo',
  full_name='pfs.RepoAuthInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_level', full_name='pfs.RepoAuthInfo.access_level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=555,
  serialized_end=604,
)


_BRANCHINFO = _descriptor.Descriptor(
  name='BranchInfo',
  full_name='pfs.BranchInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.BranchInfo.branch', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='head', full_name='pfs.BranchInfo.head', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pfs.BranchInfo.provenance', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subvenance', full_name='pfs.BranchInfo.subvenance', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direct_provenance', full_name='pfs.BranchInfo.direct_provenance', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='pfs.BranchInfo.trigger', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='pfs.BranchInfo.name', index=6,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=826,
)


_BRANCHINFOS = _descriptor.Descriptor(
  name='BranchInfos',
  full_name='pfs.BranchInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch_info', full_name='pfs.BranchInfos.branch_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=828,
  serialized_end=879,
)


_TRIGGER = _descriptor.Descriptor(
  name='Trigger',
  full_name='pfs.Trigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.Trigger.branch', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all', full_name='pfs.Trigger.all', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cron_spec', full_name='pfs.Trigger.cron_spec', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='pfs.Trigger.size', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commits', full_name='pfs.Trigger.commits', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=881,
  serialized_end=969,
)


_COMMITORIGIN = _descriptor.Descriptor(
  name='CommitOrigin',
  full_name='pfs.CommitOrigin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='pfs.CommitOrigin.kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1016,
)


_COMMIT = _descriptor.Descriptor(
  name='Commit',
  full_name='pfs.Commit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.Commit.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='pfs.Commit.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1063,
)


_COMMITRANGE = _descriptor.Descriptor(
  name='CommitRange',
  full_name='pfs.CommitRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lower', full_name='pfs.CommitRange.lower', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper', full_name='pfs.CommitRange.upper', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1065,
  serialized_end=1134,
)


_COMMITPROVENANCE = _descriptor.Descriptor(
  name='CommitProvenance',
  full_name='pfs.CommitProvenance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.CommitProvenance.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.CommitProvenance.branch', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1212,
)


_COMMITINFO = _descriptor.Descriptor(
  name='CommitInfo',
  full_name='pfs.CommitInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.CommitInfo.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.CommitInfo.branch', index=1,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='pfs.CommitInfo.origin', index=2,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs.CommitInfo.description', index=3,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_commit', full_name='pfs.CommitInfo.parent_commit', index=4,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child_commits', full_name='pfs.CommitInfo.child_commits', index=5,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='started', full_name='pfs.CommitInfo.started', index=6,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finished', full_name='pfs.CommitInfo.finished', index=7,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.CommitInfo.size_bytes', index=8,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pfs.CommitInfo.provenance', index=9,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ready_provenance', full_name='pfs.CommitInfo.ready_provenance', index=10,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subvenance', full_name='pfs.CommitInfo.subvenance', index=11,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tree', full_name='pfs.CommitInfo.tree', index=12,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trees', full_name='pfs.CommitInfo.trees', index=13,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datums', full_name='pfs.CommitInfo.datums', index=14,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subvenant_commits_success', full_name='pfs.CommitInfo.subvenant_commits_success', index=15,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subvenant_commits_failure', full_name='pfs.CommitInfo.subvenant_commits_failure', index=16,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subvenant_commits_total', full_name='pfs.CommitInfo.subvenant_commits_total', index=17,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1215,
  serialized_end=1830,
)


_FILEINFO = _descriptor.Descriptor(
  name='FileInfo',
  full_name='pfs.FileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs.FileInfo.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='pfs.FileInfo.file_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.FileInfo.size_bytes', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='committed', full_name='pfs.FileInfo.committed', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='pfs.FileInfo.children', index=4,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects', full_name='pfs.FileInfo.objects', index=5,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blockRefs', full_name='pfs.FileInfo.blockRefs', index=6,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='pfs.FileInfo.hash', index=7,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1833,
  serialized_end=2065,
)


_BYTERANGE = _descriptor.Descriptor(
  name='ByteRange',
  full_name='pfs.ByteRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lower', full_name='pfs.ByteRange.lower', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper', full_name='pfs.ByteRange.upper', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2067,
  serialized_end=2108,
)


_BLOCKREF = _descriptor.Descriptor(
  name='BlockRef',
  full_name='pfs.BlockRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='pfs.BlockRef.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='pfs.BlockRef.range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2110,
  serialized_end=2178,
)


_OBJECTINFO = _descriptor.Descriptor(
  name='ObjectInfo',
  full_name='pfs.ObjectInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='pfs.ObjectInfo.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_ref', full_name='pfs.ObjectInfo.block_ref', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2180,
  serialized_end=2255,
)


_COMPACTION = _descriptor.Descriptor(
  name='Compaction',
  full_name='pfs.Compaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input_prefixes', full_name='pfs.Compaction.input_prefixes', index=0,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2257,
  serialized_end=2293,
)


_SHARD = _descriptor.Descriptor(
  name='Shard',
  full_name='pfs.Shard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='compaction', full_name='pfs.Shard.compaction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='pfs.Shard.range', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_path', full_name='pfs.Shard.output_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2295,
  serialized_end=2391,
)


_PATHRANGE = _descriptor.Descriptor(
  name='PathRange',
  full_name='pfs.PathRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lower', full_name='pfs.PathRange.lower', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper', full_name='pfs.PathRange.upper', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2393,
  serialized_end=2434,
)


_CREATEREPOREQUEST = _descriptor.Descriptor(
  name='CreateRepoRequest',
  full_name='pfs.CreateRepoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.CreateRepoRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs.CreateRepoRequest.description', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='pfs.CreateRepoRequest.update', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2436,
  serialized_end=2523,
)


_INSPECTREPOREQUEST = _descriptor.Descriptor(
  name='InspectRepoRequest',
  full_name='pfs.InspectRepoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.InspectRepoRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2525,
  serialized_end=2570,
)


_LISTREPOREQUEST = _descriptor.Descriptor(
  name='ListRepoRequest',
  full_name='pfs.ListRepoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2572,
  serialized_end=2595,
)


_LISTREPORESPONSE = _descriptor.Descriptor(
  name='ListRepoResponse',
  full_name='pfs.ListRepoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo_info', full_name='pfs.ListRepoResponse.repo_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2597,
  serialized_end=2649,
)


_DELETEREPOREQUEST = _descriptor.Descriptor(
  name='DeleteRepoRequest',
  full_name='pfs.DeleteRepoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.DeleteRepoRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force', full_name='pfs.DeleteRepoRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='all', full_name='pfs.DeleteRepoRequest.all', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='split_transaction', full_name='pfs.DeleteRepoRequest.split_transaction', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2651,
  serialized_end=2750,
)


_STARTCOMMITREQUEST = _descriptor.Descriptor(
  name='StartCommitRequest',
  full_name='pfs.StartCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='pfs.StartCommitRequest.parent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs.StartCommitRequest.description', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.StartCommitRequest.branch', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pfs.StartCommitRequest.provenance', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2753,
  serialized_end=2888,
)


_BUILDCOMMITREQUEST = _descriptor.Descriptor(
  name='BuildCommitRequest',
  full_name='pfs.BuildCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='pfs.BuildCommitRequest.parent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.BuildCommitRequest.branch', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='pfs.BuildCommitRequest.origin', index=2,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pfs.BuildCommitRequest.provenance', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tree', full_name='pfs.BuildCommitRequest.tree', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trees', full_name='pfs.BuildCommitRequest.trees', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datums', full_name='pfs.BuildCommitRequest.datums', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ID', full_name='pfs.BuildCommitRequest.ID', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.BuildCommitRequest.size_bytes', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='started', full_name='pfs.BuildCommitRequest.started', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finished', full_name='pfs.BuildCommitRequest.finished', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2891,
  serialized_end=3247,
)


_FINISHCOMMITREQUEST = _descriptor.Descriptor(
  name='FinishCommitRequest',
  full_name='pfs.FinishCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.FinishCommitRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs.FinishCommitRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tree', full_name='pfs.FinishCommitRequest.tree', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trees', full_name='pfs.FinishCommitRequest.trees', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datums', full_name='pfs.FinishCommitRequest.datums', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.FinishCommitRequest.size_bytes', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty', full_name='pfs.FinishCommitRequest.empty', index=6,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3250,
  serialized_end=3440,
)


_INSPECTCOMMITREQUEST = _descriptor.Descriptor(
  name='InspectCommitRequest',
  full_name='pfs.InspectCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.InspectCommitRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_state', full_name='pfs.InspectCommitRequest.block_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3442,
  serialized_end=3532,
)


_LISTCOMMITREQUEST = _descriptor.Descriptor(
  name='ListCommitRequest',
  full_name='pfs.ListCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.ListCommitRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from', full_name='pfs.ListCommitRequest.from', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='pfs.ListCommitRequest.to', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number', full_name='pfs.ListCommitRequest.number', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse', full_name='pfs.ListCommitRequest.reverse', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3535,
  serialized_end=3664,
)


_COMMITINFOS = _descriptor.Descriptor(
  name='CommitInfos',
  full_name='pfs.CommitInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_info', full_name='pfs.CommitInfos.commit_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3666,
  serialized_end=3717,
)


_CREATEBRANCHREQUEST = _descriptor.Descriptor(
  name='CreateBranchRequest',
  full_name='pfs.CreateBranchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='head', full_name='pfs.CreateBranchRequest.head', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='s_branch', full_name='pfs.CreateBranchRequest.s_branch', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.CreateBranchRequest.branch', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pfs.CreateBranchRequest.provenance', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='pfs.CreateBranchRequest.trigger', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3720,
  serialized_end=3879,
)


_INSPECTBRANCHREQUEST = _descriptor.Descriptor(
  name='InspectBranchRequest',
  full_name='pfs.InspectBranchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.InspectBranchRequest.branch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3881,
  serialized_end=3932,
)


_LISTBRANCHREQUEST = _descriptor.Descriptor(
  name='ListBranchRequest',
  full_name='pfs.ListBranchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.ListBranchRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse', full_name='pfs.ListBranchRequest.reverse', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3934,
  serialized_end=3995,
)


_DELETEBRANCHREQUEST = _descriptor.Descriptor(
  name='DeleteBranchRequest',
  full_name='pfs.DeleteBranchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.DeleteBranchRequest.branch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='force', full_name='pfs.DeleteBranchRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3997,
  serialized_end=4062,
)


_DELETECOMMITREQUEST = _descriptor.Descriptor(
  name='DeleteCommitRequest',
  full_name='pfs.DeleteCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.DeleteCommitRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4064,
  serialized_end=4114,
)


_FLUSHCOMMITREQUEST = _descriptor.Descriptor(
  name='FlushCommitRequest',
  full_name='pfs.FlushCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commits', full_name='pfs.FlushCommitRequest.commits', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_repos', full_name='pfs.FlushCommitRequest.to_repos', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4116,
  serialized_end=4195,
)


_SUBSCRIBECOMMITREQUEST = _descriptor.Descriptor(
  name='SubscribeCommitRequest',
  full_name='pfs.SubscribeCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs.SubscribeCommitRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs.SubscribeCommitRequest.branch', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prov', full_name='pfs.SubscribeCommitRequest.prov', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from', full_name='pfs.SubscribeCommitRequest.from', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='pfs.SubscribeCommitRequest.state', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4198,
  serialized_end=4360,
)


_GETFILEREQUEST = _descriptor.Descriptor(
  name='GetFileRequest',
  full_name='pfs.GetFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs.GetFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_bytes', full_name='pfs.GetFileRequest.offset_bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.GetFileRequest.size_bytes', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4362,
  serialized_end=4445,
)


_OVERWRITEINDEX = _descriptor.Descriptor(
  name='OverwriteIndex',
  full_name='pfs.OverwriteIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='pfs.OverwriteIndex.index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4447,
  serialized_end=4478,
)


_PUTFILEREQUEST = _descriptor.Descriptor(
  name='PutFileRequest',
  full_name='pfs.PutFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs.PutFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pfs.PutFileRequest.value', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='pfs.PutFileRequest.url', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='pfs.PutFileRequest.recursive', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delimiter', full_name='pfs.PutFileRequest.delimiter', index=4,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_file_datums', full_name='pfs.PutFileRequest.target_file_datums', index=5,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_file_bytes', full_name='pfs.PutFileRequest.target_file_bytes', index=6,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_records', full_name='pfs.PutFileRequest.header_records', index=7,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overwrite_index', full_name='pfs.PutFileRequest.overwrite_index', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete', full_name='pfs.PutFileRequest.delete', index=9,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4481,
  serialized_end=4757,
)


_PUTFILERECORD = _descriptor.Descriptor(
  name='PutFileRecord',
  full_name='pfs.PutFileRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.PutFileRecord.size_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_hash', full_name='pfs.PutFileRecord.object_hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overwrite_index', full_name='pfs.PutFileRecord.overwrite_index', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_ref', full_name='pfs.PutFileRecord.block_ref', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4760,
  serialized_end=4896,
)


_PUTFILERECORDS = _descriptor.Descriptor(
  name='PutFileRecords',
  full_name='pfs.PutFileRecords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='split', full_name='pfs.PutFileRecords.split', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='records', full_name='pfs.PutFileRecords.records', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tombstone', full_name='pfs.PutFileRecords.tombstone', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='pfs.PutFileRecords.header', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer', full_name='pfs.PutFileRecords.footer', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4899,
  serialized_end=5058,
)


_COPYFILEREQUEST = _descriptor.Descriptor(
  name='CopyFileRequest',
  full_name='pfs.CopyFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='src', full_name='pfs.CopyFileRequest.src', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst', full_name='pfs.CopyFileRequest.dst', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='pfs.CopyFileRequest.overwrite', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5060,
  serialized_end=5144,
)


_INSPECTFILEREQUEST = _descriptor.Descriptor(
  name='InspectFileRequest',
  full_name='pfs.InspectFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs.InspectFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5146,
  serialized_end=5191,
)


_LISTFILEREQUEST = _descriptor.Descriptor(
  name='ListFileRequest',
  full_name='pfs.ListFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs.ListFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full', full_name='pfs.ListFileRequest.full', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='history', full_name='pfs.ListFileRequest.history', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5193,
  serialized_end=5266,
)


_WALKFILEREQUEST = _descriptor.Descriptor(
  name='WalkFileRequest',
  full_name='pfs.WalkFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs.WalkFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5268,
  serialized_end=5310,
)


_GLOBFILEREQUEST = _descriptor.Descriptor(
  name='GlobFileRequest',
  full_name='pfs.GlobFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.GlobFileRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='pfs.GlobFileRequest.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5312,
  serialized_end=5375,
)


_FILEINFOS = _descriptor.Descriptor(
  name='FileInfos',
  full_name='pfs.FileInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_info', full_name='pfs.FileInfos.file_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5377,
  serialized_end=5422,
)


_DIFFFILEREQUEST = _descriptor.Descriptor(
  name='DiffFileRequest',
  full_name='pfs.DiffFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_file', full_name='pfs.DiffFileRequest.new_file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_file', full_name='pfs.DiffFileRequest.old_file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shallow', full_name='pfs.DiffFileRequest.shallow', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5424,
  serialized_end=5516,
)


_DIFFFILERESPONSE = _descriptor.Descriptor(
  name='DiffFileResponse',
  full_name='pfs.DiffFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_files', full_name='pfs.DiffFileResponse.new_files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_files', full_name='pfs.DiffFileResponse.old_files', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5518,
  serialized_end=5604,
)


_DELETEFILEREQUEST = _descriptor.Descriptor(
  name='DeleteFileRequest',
  full_name='pfs.DeleteFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs.DeleteFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5606,
  serialized_end=5650,
)


_FSCKREQUEST = _descriptor.Descriptor(
  name='FsckRequest',
  full_name='pfs.FsckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fix', full_name='pfs.FsckRequest.fix', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5652,
  serialized_end=5678,
)


_FSCKRESPONSE = _descriptor.Descriptor(
  name='FsckResponse',
  full_name='pfs.FsckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fix', full_name='pfs.FsckResponse.fix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='pfs.FsckResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5680,
  serialized_end=5722,
)


_FILEOPERATIONREQUESTV2 = _descriptor.Descriptor(
  name='FileOperationRequestV2',
  full_name='pfs.FileOperationRequestV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.FileOperationRequestV2.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='put_tar', full_name='pfs.FileOperationRequestV2.put_tar', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_files', full_name='pfs.FileOperationRequestV2.delete_files', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='pfs.FileOperationRequestV2.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5725,
  serialized_end=5883,
)


_PUTTARREQUESTV2 = _descriptor.Descriptor(
  name='PutTarRequestV2',
  full_name='pfs.PutTarRequestV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='pfs.PutTarRequestV2.overwrite', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='pfs.PutTarRequestV2.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='pfs.PutTarRequestV2.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5885,
  serialized_end=5948,
)


_DELETEFILESREQUESTV2 = _descriptor.Descriptor(
  name='DeleteFilesRequestV2',
  full_name='pfs.DeleteFilesRequestV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='pfs.DeleteFilesRequestV2.files', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='pfs.DeleteFilesRequestV2.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5950,
  serialized_end=6000,
)


_GETTARREQUESTV2 = _descriptor.Descriptor(
  name='GetTarRequestV2',
  full_name='pfs.GetTarRequestV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs.GetTarRequestV2.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6002,
  serialized_end=6044,
)


_DIFFFILERESPONSEV2 = _descriptor.Descriptor(
  name='DiffFileResponseV2',
  full_name='pfs.DiffFileResponseV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='old_file', full_name='pfs.DiffFileResponseV2.old_file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_file', full_name='pfs.DiffFileResponseV2.new_file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6046,
  serialized_end=6132,
)


_CREATETMPFILESETRESPONSE = _descriptor.Descriptor(
  name='CreateTmpFileSetResponse',
  full_name='pfs.CreateTmpFileSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileset_id', full_name='pfs.CreateTmpFileSetResponse.fileset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6134,
  serialized_end=6180,
)


_RENEWTMPFILESETREQUEST = _descriptor.Descriptor(
  name='RenewTmpFileSetRequest',
  full_name='pfs.RenewTmpFileSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileset_id', full_name='pfs.RenewTmpFileSetRequest.fileset_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl_seconds', full_name='pfs.RenewTmpFileSetRequest.ttl_seconds', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6182,
  serialized_end=6247,
)


_CLEARCOMMITREQUESTV2 = _descriptor.Descriptor(
  name='ClearCommitRequestV2',
  full_name='pfs.ClearCommitRequestV2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs.ClearCommitRequestV2.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6249,
  serialized_end=6300,
)


_PUTOBJECTREQUEST = _descriptor.Descriptor(
  name='PutObjectRequest',
  full_name='pfs.PutObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='pfs.PutObjectRequest.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='pfs.PutObjectRequest.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='pfs.PutObjectRequest.block', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6302,
  serialized_end=6386,
)


_CREATEOBJECTREQUEST = _descriptor.Descriptor(
  name='CreateObjectRequest',
  full_name='pfs.CreateObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='pfs.CreateObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_ref', full_name='pfs.CreateObjectRequest.block_ref', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6388,
  serialized_end=6472,
)


_GETOBJECTSREQUEST = _descriptor.Descriptor(
  name='GetObjectsRequest',
  full_name='pfs.GetObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='pfs.GetObjectsRequest.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_bytes', full_name='pfs.GetObjectsRequest.offset_bytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.GetObjectsRequest.size_bytes', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='pfs.GetObjectsRequest.total_size', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6474,
  serialized_end=6585,
)


_PUTBLOCKREQUEST = _descriptor.Descriptor(
  name='PutBlockRequest',
  full_name='pfs.PutBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='pfs.PutBlockRequest.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pfs.PutBlockRequest.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6587,
  serialized_end=6646,
)


_GETBLOCKREQUEST = _descriptor.Descriptor(
  name='GetBlockRequest',
  full_name='pfs.GetBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='pfs.GetBlockRequest.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6648,
  serialized_end=6692,
)


_GETBLOCKSREQUEST = _descriptor.Descriptor(
  name='GetBlocksRequest',
  full_name='pfs.GetBlocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockRefs', full_name='pfs.GetBlocksRequest.blockRefs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset_bytes', full_name='pfs.GetBlocksRequest.offset_bytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs.GetBlocksRequest.size_bytes', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='pfs.GetBlocksRequest.total_size', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6694,
  serialized_end=6808,
)


_LISTBLOCKREQUEST = _descriptor.Descriptor(
  name='ListBlockRequest',
  full_name='pfs.ListBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6810,
  serialized_end=6828,
)


_TAGOBJECTREQUEST = _descriptor.Descriptor(
  name='TagObjectRequest',
  full_name='pfs.TagObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='pfs.TagObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='pfs.TagObjectRequest.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6830,
  serialized_end=6901,
)


_LISTOBJECTSREQUEST = _descriptor.Descriptor(
  name='ListObjectsRequest',
  full_name='pfs.ListObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6903,
  serialized_end=6923,
)


_LISTTAGSREQUEST = _descriptor.Descriptor(
  name='ListTagsRequest',
  full_name='pfs.ListTagsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='pfs.ListTagsRequest.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_object', full_name='pfs.ListTagsRequest.include_object', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6925,
  serialized_end=6982,
)


_LISTTAGSRESPONSE = _descriptor.Descriptor(
  name='ListTagsResponse',
  full_name='pfs.ListTagsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='pfs.ListTagsResponse.tag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='pfs.ListTagsResponse.object', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6984,
  serialized_end=7054,
)


_DELETEOBJECTSREQUEST = _descriptor.Descriptor(
  name='DeleteObjectsRequest',
  full_name='pfs.DeleteObjectsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='pfs.DeleteObjectsRequest.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7056,
  serialized_end=7108,
)


_DELETEOBJECTSRESPONSE = _descriptor.Descriptor(
  name='DeleteObjectsResponse',
  full_name='pfs.DeleteObjectsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7110,
  serialized_end=7133,
)


_DELETETAGSREQUEST = _descriptor.Descriptor(
  name='DeleteTagsRequest',
  full_name='pfs.DeleteTagsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='pfs.DeleteTagsRequest.tags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7135,
  serialized_end=7178,
)


_DELETETAGSRESPONSE = _descriptor.Descriptor(
  name='DeleteTagsResponse',
  full_name='pfs.DeleteTagsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7180,
  serialized_end=7200,
)


_CHECKOBJECTREQUEST = _descriptor.Descriptor(
  name='CheckObjectRequest',
  full_name='pfs.CheckObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='pfs.CheckObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7202,
  serialized_end=7251,
)


_CHECKOBJECTRESPONSE = _descriptor.Descriptor(
  name='CheckObjectResponse',
  full_name='pfs.CheckObjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exists', full_name='pfs.CheckObjectResponse.exists', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7253,
  serialized_end=7290,
)


_OBJECTS = _descriptor.Descriptor(
  name='Objects',
  full_name='pfs.Objects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='pfs.Objects.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7292,
  serialized_end=7331,
)


_PUTOBJDIRECTREQUEST = _descriptor.Descriptor(
  name='PutObjDirectRequest',
  full_name='pfs.PutObjDirectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='obj', full_name='pfs.PutObjDirectRequest.obj', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pfs.PutObjDirectRequest.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7333,
  serialized_end=7382,
)


_GETOBJDIRECTREQUEST = _descriptor.Descriptor(
  name='GetObjDirectRequest',
  full_name='pfs.GetObjDirectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='obj', full_name='pfs.GetObjDirectRequest.obj', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7384,
  serialized_end=7418,
)


_DELETEOBJDIRECTREQUEST = _descriptor.Descriptor(
  name='DeleteObjDirectRequest',
  full_name='pfs.DeleteObjDirectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='pfs.DeleteObjDirectRequest.object', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='pfs.DeleteObjDirectRequest.prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7420,
  serialized_end=7476,
)


_OBJECTINDEX_OBJECTSENTRY = _descriptor.Descriptor(
  name='ObjectsEntry',
  full_name='pfs.ObjectIndex.ObjectsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='pfs.ObjectIndex.ObjectsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pfs.ObjectIndex.ObjectsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7584,
  serialized_end=7645,
)

_OBJECTINDEX_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='pfs.ObjectIndex.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='pfs.ObjectIndex.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='pfs.ObjectIndex.TagsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7647,
  serialized_end=7703,
)

_OBJECTINDEX = _descriptor.Descriptor(
  name='ObjectIndex',
  full_name='pfs.ObjectIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='pfs.ObjectIndex.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='pfs.ObjectIndex.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTINDEX_OBJECTSENTRY, _OBJECTINDEX_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7479,
  serialized_end=7703,
)

_BRANCH.fields_by_name['repo'].message_type = _REPO
_FILE.fields_by_name['commit'].message_type = _COMMIT
_REPOINFO.fields_by_name['repo'].message_type = _REPO
_REPOINFO.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REPOINFO.fields_by_name['branches'].message_type = _BRANCH
_REPOINFO.fields_by_name['auth_info'].message_type = _REPOAUTHINFO
_REPOAUTHINFO.fields_by_name['access_level'].enum_type = client_dot_auth_dot_auth__pb2._SCOPE
_BRANCHINFO.fields_by_name['branch'].message_type = _BRANCH
_BRANCHINFO.fields_by_name['head'].message_type = _COMMIT
_BRANCHINFO.fields_by_name['provenance'].message_type = _BRANCH
_BRANCHINFO.fields_by_name['subvenance'].message_type = _BRANCH
_BRANCHINFO.fields_by_name['direct_provenance'].message_type = _BRANCH
_BRANCHINFO.fields_by_name['trigger'].message_type = _TRIGGER
_BRANCHINFOS.fields_by_name['branch_info'].message_type = _BRANCHINFO
_COMMITORIGIN.fields_by_name['kind'].enum_type = _ORIGINKIND
_COMMIT.fields_by_name['repo'].message_type = _REPO
_COMMITRANGE.fields_by_name['lower'].message_type = _COMMIT
_COMMITRANGE.fields_by_name['upper'].message_type = _COMMIT
_COMMITPROVENANCE.fields_by_name['commit'].message_type = _COMMIT
_COMMITPROVENANCE.fields_by_name['branch'].message_type = _BRANCH
_COMMITINFO.fields_by_name['commit'].message_type = _COMMIT
_COMMITINFO.fields_by_name['branch'].message_type = _BRANCH
_COMMITINFO.fields_by_name['origin'].message_type = _COMMITORIGIN
_COMMITINFO.fields_by_name['parent_commit'].message_type = _COMMIT
_COMMITINFO.fields_by_name['child_commits'].message_type = _COMMIT
_COMMITINFO.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMITINFO.fields_by_name['finished'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMITINFO.fields_by_name['provenance'].message_type = _COMMITPROVENANCE
_COMMITINFO.fields_by_name['subvenance'].message_type = _COMMITRANGE
_COMMITINFO.fields_by_name['tree'].message_type = _OBJECT
_COMMITINFO.fields_by_name['trees'].message_type = _OBJECT
_COMMITINFO.fields_by_name['datums'].message_type = _OBJECT
_FILEINFO.fields_by_name['file'].message_type = _FILE
_FILEINFO.fields_by_name['file_type'].enum_type = _FILETYPE
_FILEINFO.fields_by_name['committed'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FILEINFO.fields_by_name['objects'].message_type = _OBJECT
_FILEINFO.fields_by_name['blockRefs'].message_type = _BLOCKREF
_BLOCKREF.fields_by_name['block'].message_type = _BLOCK
_BLOCKREF.fields_by_name['range'].message_type = _BYTERANGE
_OBJECTINFO.fields_by_name['object'].message_type = _OBJECT
_OBJECTINFO.fields_by_name['block_ref'].message_type = _BLOCKREF
_SHARD.fields_by_name['compaction'].message_type = _COMPACTION
_SHARD.fields_by_name['range'].message_type = _PATHRANGE
_CREATEREPOREQUEST.fields_by_name['repo'].message_type = _REPO
_INSPECTREPOREQUEST.fields_by_name['repo'].message_type = _REPO
_LISTREPORESPONSE.fields_by_name['repo_info'].message_type = _REPOINFO
_DELETEREPOREQUEST.fields_by_name['repo'].message_type = _REPO
_STARTCOMMITREQUEST.fields_by_name['parent'].message_type = _COMMIT
_STARTCOMMITREQUEST.fields_by_name['provenance'].message_type = _COMMITPROVENANCE
_BUILDCOMMITREQUEST.fields_by_name['parent'].message_type = _COMMIT
_BUILDCOMMITREQUEST.fields_by_name['origin'].message_type = _COMMITORIGIN
_BUILDCOMMITREQUEST.fields_by_name['provenance'].message_type = _COMMITPROVENANCE
_BUILDCOMMITREQUEST.fields_by_name['tree'].message_type = _OBJECT
_BUILDCOMMITREQUEST.fields_by_name['trees'].message_type = _OBJECT
_BUILDCOMMITREQUEST.fields_by_name['datums'].message_type = _OBJECT
_BUILDCOMMITREQUEST.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BUILDCOMMITREQUEST.fields_by_name['finished'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FINISHCOMMITREQUEST.fields_by_name['commit'].message_type = _COMMIT
_FINISHCOMMITREQUEST.fields_by_name['tree'].message_type = _OBJECT
_FINISHCOMMITREQUEST.fields_by_name['trees'].message_type = _OBJECT
_FINISHCOMMITREQUEST.fields_by_name['datums'].message_type = _OBJECT
_INSPECTCOMMITREQUEST.fields_by_name['commit'].message_type = _COMMIT
_INSPECTCOMMITREQUEST.fields_by_name['block_state'].enum_type = _COMMITSTATE
_LISTCOMMITREQUEST.fields_by_name['repo'].message_type = _REPO
_LISTCOMMITREQUEST.fields_by_name['from'].message_type = _COMMIT
_LISTCOMMITREQUEST.fields_by_name['to'].message_type = _COMMIT
_COMMITINFOS.fields_by_name['commit_info'].message_type = _COMMITINFO
_CREATEBRANCHREQUEST.fields_by_name['head'].message_type = _COMMIT
_CREATEBRANCHREQUEST.fields_by_name['branch'].message_type = _BRANCH
_CREATEBRANCHREQUEST.fields_by_name['provenance'].message_type = _BRANCH
_CREATEBRANCHREQUEST.fields_by_name['trigger'].message_type = _TRIGGER
_INSPECTBRANCHREQUEST.fields_by_name['branch'].message_type = _BRANCH
_LISTBRANCHREQUEST.fields_by_name['repo'].message_type = _REPO
_DELETEBRANCHREQUEST.fields_by_name['branch'].message_type = _BRANCH
_DELETECOMMITREQUEST.fields_by_name['commit'].message_type = _COMMIT
_FLUSHCOMMITREQUEST.fields_by_name['commits'].message_type = _COMMIT
_FLUSHCOMMITREQUEST.fields_by_name['to_repos'].message_type = _REPO
_SUBSCRIBECOMMITREQUEST.fields_by_name['repo'].message_type = _REPO
_SUBSCRIBECOMMITREQUEST.fields_by_name['prov'].message_type = _COMMITPROVENANCE
_SUBSCRIBECOMMITREQUEST.fields_by_name['from'].message_type = _COMMIT
_SUBSCRIBECOMMITREQUEST.fields_by_name['state'].enum_type = _COMMITSTATE
_GETFILEREQUEST.fields_by_name['file'].message_type = _FILE
_PUTFILEREQUEST.fields_by_name['file'].message_type = _FILE
_PUTFILEREQUEST.fields_by_name['delimiter'].enum_type = _DELIMITER
_PUTFILEREQUEST.fields_by_name['overwrite_index'].message_type = _OVERWRITEINDEX
_PUTFILERECORD.fields_by_name['overwrite_index'].message_type = _OVERWRITEINDEX
_PUTFILERECORD.fields_by_name['block_ref'].message_type = _BLOCKREF
_PUTFILERECORDS.fields_by_name['records'].message_type = _PUTFILERECORD
_PUTFILERECORDS.fields_by_name['header'].message_type = _PUTFILERECORD
_PUTFILERECORDS.fields_by_name['footer'].message_type = _PUTFILERECORD
_COPYFILEREQUEST.fields_by_name['src'].message_type = _FILE
_COPYFILEREQUEST.fields_by_name['dst'].message_type = _FILE
_INSPECTFILEREQUEST.fields_by_name['file'].message_type = _FILE
_LISTFILEREQUEST.fields_by_name['file'].message_type = _FILE
_WALKFILEREQUEST.fields_by_name['file'].message_type = _FILE
_GLOBFILEREQUEST.fields_by_name['commit'].message_type = _COMMIT
_FILEINFOS.fields_by_name['file_info'].message_type = _FILEINFO
_DIFFFILEREQUEST.fields_by_name['new_file'].message_type = _FILE
_DIFFFILEREQUEST.fields_by_name['old_file'].message_type = _FILE
_DIFFFILERESPONSE.fields_by_name['new_files'].message_type = _FILEINFO
_DIFFFILERESPONSE.fields_by_name['old_files'].message_type = _FILEINFO
_DELETEFILEREQUEST.fields_by_name['file'].message_type = _FILE
_FILEOPERATIONREQUESTV2.fields_by_name['commit'].message_type = _COMMIT
_FILEOPERATIONREQUESTV2.fields_by_name['put_tar'].message_type = _PUTTARREQUESTV2
_FILEOPERATIONREQUESTV2.fields_by_name['delete_files'].message_type = _DELETEFILESREQUESTV2
_FILEOPERATIONREQUESTV2.oneofs_by_name['operation'].fields.append(
  _FILEOPERATIONREQUESTV2.fields_by_name['put_tar'])
_FILEOPERATIONREQUESTV2.fields_by_name['put_tar'].containing_oneof = _FILEOPERATIONREQUESTV2.oneofs_by_name['operation']
_FILEOPERATIONREQUESTV2.oneofs_by_name['operation'].fields.append(
  _FILEOPERATIONREQUESTV2.fields_by_name['delete_files'])
_FILEOPERATIONREQUESTV2.fields_by_name['delete_files'].containing_oneof = _FILEOPERATIONREQUESTV2.oneofs_by_name['operation']
_GETTARREQUESTV2.fields_by_name['file'].message_type = _FILE
_DIFFFILERESPONSEV2.fields_by_name['old_file'].message_type = _FILEINFO
_DIFFFILERESPONSEV2.fields_by_name['new_file'].message_type = _FILEINFO
_CLEARCOMMITREQUESTV2.fields_by_name['commit'].message_type = _COMMIT
_PUTOBJECTREQUEST.fields_by_name['tags'].message_type = _TAG
_PUTOBJECTREQUEST.fields_by_name['block'].message_type = _BLOCK
_CREATEOBJECTREQUEST.fields_by_name['object'].message_type = _OBJECT
_CREATEOBJECTREQUEST.fields_by_name['block_ref'].message_type = _BLOCKREF
_GETOBJECTSREQUEST.fields_by_name['objects'].message_type = _OBJECT
_PUTBLOCKREQUEST.fields_by_name['block'].message_type = _BLOCK
_GETBLOCKREQUEST.fields_by_name['block'].message_type = _BLOCK
_GETBLOCKSREQUEST.fields_by_name['blockRefs'].message_type = _BLOCKREF
_TAGOBJECTREQUEST.fields_by_name['object'].message_type = _OBJECT
_TAGOBJECTREQUEST.fields_by_name['tags'].message_type = _TAG
_LISTTAGSRESPONSE.fields_by_name['tag'].message_type = _TAG
_LISTTAGSRESPONSE.fields_by_name['object'].message_type = _OBJECT
_DELETEOBJECTSREQUEST.fields_by_name['objects'].message_type = _OBJECT
_DELETETAGSREQUEST.fields_by_name['tags'].message_type = _TAG
_CHECKOBJECTREQUEST.fields_by_name['object'].message_type = _OBJECT
_OBJECTS.fields_by_name['objects'].message_type = _OBJECT
_OBJECTINDEX_OBJECTSENTRY.fields_by_name['value'].message_type = _BLOCKREF
_OBJECTINDEX_OBJECTSENTRY.containing_type = _OBJECTINDEX
_OBJECTINDEX_TAGSENTRY.fields_by_name['value'].message_type = _OBJECT
_OBJECTINDEX_TAGSENTRY.containing_type = _OBJECTINDEX
_OBJECTINDEX.fields_by_name['objects'].message_type = _OBJECTINDEX_OBJECTSENTRY
_OBJECTINDEX.fields_by_name['tags'].message_type = _OBJECTINDEX_TAGSENTRY
DESCRIPTOR.message_types_by_name['Repo'] = _REPO
DESCRIPTOR.message_types_by_name['Branch'] = _BRANCH
DESCRIPTOR.message_types_by_name['File'] = _FILE
DESCRIPTOR.message_types_by_name['Block'] = _BLOCK
DESCRIPTOR.message_types_by_name['Object'] = _OBJECT
DESCRIPTOR.message_types_by_name['Tag'] = _TAG
DESCRIPTOR.message_types_by_name['RepoInfo'] = _REPOINFO
DESCRIPTOR.message_types_by_name['RepoAuthInfo'] = _REPOAUTHINFO
DESCRIPTOR.message_types_by_name['BranchInfo'] = _BRANCHINFO
DESCRIPTOR.message_types_by_name['BranchInfos'] = _BRANCHINFOS
DESCRIPTOR.message_types_by_name['Trigger'] = _TRIGGER
DESCRIPTOR.message_types_by_name['CommitOrigin'] = _COMMITORIGIN
DESCRIPTOR.message_types_by_name['Commit'] = _COMMIT
DESCRIPTOR.message_types_by_name['CommitRange'] = _COMMITRANGE
DESCRIPTOR.message_types_by_name['CommitProvenance'] = _COMMITPROVENANCE
DESCRIPTOR.message_types_by_name['CommitInfo'] = _COMMITINFO
DESCRIPTOR.message_types_by_name['FileInfo'] = _FILEINFO
DESCRIPTOR.message_types_by_name['ByteRange'] = _BYTERANGE
DESCRIPTOR.message_types_by_name['BlockRef'] = _BLOCKREF
DESCRIPTOR.message_types_by_name['ObjectInfo'] = _OBJECTINFO
DESCRIPTOR.message_types_by_name['Compaction'] = _COMPACTION
DESCRIPTOR.message_types_by_name['Shard'] = _SHARD
DESCRIPTOR.message_types_by_name['PathRange'] = _PATHRANGE
DESCRIPTOR.message_types_by_name['CreateRepoRequest'] = _CREATEREPOREQUEST
DESCRIPTOR.message_types_by_name['InspectRepoRequest'] = _INSPECTREPOREQUEST
DESCRIPTOR.message_types_by_name['ListRepoRequest'] = _LISTREPOREQUEST
DESCRIPTOR.message_types_by_name['ListRepoResponse'] = _LISTREPORESPONSE
DESCRIPTOR.message_types_by_name['DeleteRepoRequest'] = _DELETEREPOREQUEST
DESCRIPTOR.message_types_by_name['StartCommitRequest'] = _STARTCOMMITREQUEST
DESCRIPTOR.message_types_by_name['BuildCommitRequest'] = _BUILDCOMMITREQUEST
DESCRIPTOR.message_types_by_name['FinishCommitRequest'] = _FINISHCOMMITREQUEST
DESCRIPTOR.message_types_by_name['InspectCommitRequest'] = _INSPECTCOMMITREQUEST
DESCRIPTOR.message_types_by_name['ListCommitRequest'] = _LISTCOMMITREQUEST
DESCRIPTOR.message_types_by_name['CommitInfos'] = _COMMITINFOS
DESCRIPTOR.message_types_by_name['CreateBranchRequest'] = _CREATEBRANCHREQUEST
DESCRIPTOR.message_types_by_name['InspectBranchRequest'] = _INSPECTBRANCHREQUEST
DESCRIPTOR.message_types_by_name['ListBranchRequest'] = _LISTBRANCHREQUEST
DESCRIPTOR.message_types_by_name['DeleteBranchRequest'] = _DELETEBRANCHREQUEST
DESCRIPTOR.message_types_by_name['DeleteCommitRequest'] = _DELETECOMMITREQUEST
DESCRIPTOR.message_types_by_name['FlushCommitRequest'] = _FLUSHCOMMITREQUEST
DESCRIPTOR.message_types_by_name['SubscribeCommitRequest'] = _SUBSCRIBECOMMITREQUEST
DESCRIPTOR.message_types_by_name['GetFileRequest'] = _GETFILEREQUEST
DESCRIPTOR.message_types_by_name['OverwriteIndex'] = _OVERWRITEINDEX
DESCRIPTOR.message_types_by_name['PutFileRequest'] = _PUTFILEREQUEST
DESCRIPTOR.message_types_by_name['PutFileRecord'] = _PUTFILERECORD
DESCRIPTOR.message_types_by_name['PutFileRecords'] = _PUTFILERECORDS
DESCRIPTOR.message_types_by_name['CopyFileRequest'] = _COPYFILEREQUEST
DESCRIPTOR.message_types_by_name['InspectFileRequest'] = _INSPECTFILEREQUEST
DESCRIPTOR.message_types_by_name['ListFileRequest'] = _LISTFILEREQUEST
DESCRIPTOR.message_types_by_name['WalkFileRequest'] = _WALKFILEREQUEST
DESCRIPTOR.message_types_by_name['GlobFileRequest'] = _GLOBFILEREQUEST
DESCRIPTOR.message_types_by_name['FileInfos'] = _FILEINFOS
DESCRIPTOR.message_types_by_name['DiffFileRequest'] = _DIFFFILEREQUEST
DESCRIPTOR.message_types_by_name['DiffFileResponse'] = _DIFFFILERESPONSE
DESCRIPTOR.message_types_by_name['DeleteFileRequest'] = _DELETEFILEREQUEST
DESCRIPTOR.message_types_by_name['FsckRequest'] = _FSCKREQUEST
DESCRIPTOR.message_types_by_name['FsckResponse'] = _FSCKRESPONSE
DESCRIPTOR.message_types_by_name['FileOperationRequestV2'] = _FILEOPERATIONREQUESTV2
DESCRIPTOR.message_types_by_name['PutTarRequestV2'] = _PUTTARREQUESTV2
DESCRIPTOR.message_types_by_name['DeleteFilesRequestV2'] = _DELETEFILESREQUESTV2
DESCRIPTOR.message_types_by_name['GetTarRequestV2'] = _GETTARREQUESTV2
DESCRIPTOR.message_types_by_name['DiffFileResponseV2'] = _DIFFFILERESPONSEV2
DESCRIPTOR.message_types_by_name['CreateTmpFileSetResponse'] = _CREATETMPFILESETRESPONSE
DESCRIPTOR.message_types_by_name['RenewTmpFileSetRequest'] = _RENEWTMPFILESETREQUEST
DESCRIPTOR.message_types_by_name['ClearCommitRequestV2'] = _CLEARCOMMITREQUESTV2
DESCRIPTOR.message_types_by_name['PutObjectRequest'] = _PUTOBJECTREQUEST
DESCRIPTOR.message_types_by_name['CreateObjectRequest'] = _CREATEOBJECTREQUEST
DESCRIPTOR.message_types_by_name['GetObjectsRequest'] = _GETOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['PutBlockRequest'] = _PUTBLOCKREQUEST
DESCRIPTOR.message_types_by_name['GetBlockRequest'] = _GETBLOCKREQUEST
DESCRIPTOR.message_types_by_name['GetBlocksRequest'] = _GETBLOCKSREQUEST
DESCRIPTOR.message_types_by_name['ListBlockRequest'] = _LISTBLOCKREQUEST
DESCRIPTOR.message_types_by_name['TagObjectRequest'] = _TAGOBJECTREQUEST
DESCRIPTOR.message_types_by_name['ListObjectsRequest'] = _LISTOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['ListTagsRequest'] = _LISTTAGSREQUEST
DESCRIPTOR.message_types_by_name['ListTagsResponse'] = _LISTTAGSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteObjectsRequest'] = _DELETEOBJECTSREQUEST
DESCRIPTOR.message_types_by_name['DeleteObjectsResponse'] = _DELETEOBJECTSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteTagsRequest'] = _DELETETAGSREQUEST
DESCRIPTOR.message_types_by_name['DeleteTagsResponse'] = _DELETETAGSRESPONSE
DESCRIPTOR.message_types_by_name['CheckObjectRequest'] = _CHECKOBJECTREQUEST
DESCRIPTOR.message_types_by_name['CheckObjectResponse'] = _CHECKOBJECTRESPONSE
DESCRIPTOR.message_types_by_name['Objects'] = _OBJECTS
DESCRIPTOR.message_types_by_name['PutObjDirectRequest'] = _PUTOBJDIRECTREQUEST
DESCRIPTOR.message_types_by_name['GetObjDirectRequest'] = _GETOBJDIRECTREQUEST
DESCRIPTOR.message_types_by_name['DeleteObjDirectRequest'] = _DELETEOBJDIRECTREQUEST
DESCRIPTOR.message_types_by_name['ObjectIndex'] = _OBJECTINDEX
DESCRIPTOR.enum_types_by_name['OriginKind'] = _ORIGINKIND
DESCRIPTOR.enum_types_by_name['FileType'] = _FILETYPE
DESCRIPTOR.enum_types_by_name['CommitState'] = _COMMITSTATE
DESCRIPTOR.enum_types_by_name['Delimiter'] = _DELIMITER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Repo = _reflection.GeneratedProtocolMessageType('Repo', (_message.Message,), {
  'DESCRIPTOR' : _REPO,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Repo)
  })
_sym_db.RegisterMessage(Repo)

Branch = _reflection.GeneratedProtocolMessageType('Branch', (_message.Message,), {
  'DESCRIPTOR' : _BRANCH,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Branch)
  })
_sym_db.RegisterMessage(Branch)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
  'DESCRIPTOR' : _FILE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.File)
  })
_sym_db.RegisterMessage(File)

Block = _reflection.GeneratedProtocolMessageType('Block', (_message.Message,), {
  'DESCRIPTOR' : _BLOCK,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Block)
  })
_sym_db.RegisterMessage(Block)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Object)
  })
_sym_db.RegisterMessage(Object)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Tag)
  })
_sym_db.RegisterMessage(Tag)

RepoInfo = _reflection.GeneratedProtocolMessageType('RepoInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPOINFO,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.RepoInfo)
  })
_sym_db.RegisterMessage(RepoInfo)

RepoAuthInfo = _reflection.GeneratedProtocolMessageType('RepoAuthInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPOAUTHINFO,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.RepoAuthInfo)
  })
_sym_db.RegisterMessage(RepoAuthInfo)

BranchInfo = _reflection.GeneratedProtocolMessageType('BranchInfo', (_message.Message,), {
  'DESCRIPTOR' : _BRANCHINFO,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.BranchInfo)
  })
_sym_db.RegisterMessage(BranchInfo)

BranchInfos = _reflection.GeneratedProtocolMessageType('BranchInfos', (_message.Message,), {
  'DESCRIPTOR' : _BRANCHINFOS,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.BranchInfos)
  })
_sym_db.RegisterMessage(BranchInfos)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGER,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Trigger)
  })
_sym_db.RegisterMessage(Trigger)

CommitOrigin = _reflection.GeneratedProtocolMessageType('CommitOrigin', (_message.Message,), {
  'DESCRIPTOR' : _COMMITORIGIN,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CommitOrigin)
  })
_sym_db.RegisterMessage(CommitOrigin)

Commit = _reflection.GeneratedProtocolMessageType('Commit', (_message.Message,), {
  'DESCRIPTOR' : _COMMIT,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Commit)
  })
_sym_db.RegisterMessage(Commit)

CommitRange = _reflection.GeneratedProtocolMessageType('CommitRange', (_message.Message,), {
  'DESCRIPTOR' : _COMMITRANGE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CommitRange)
  })
_sym_db.RegisterMessage(CommitRange)

CommitProvenance = _reflection.GeneratedProtocolMessageType('CommitProvenance', (_message.Message,), {
  'DESCRIPTOR' : _COMMITPROVENANCE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CommitProvenance)
  })
_sym_db.RegisterMessage(CommitProvenance)

CommitInfo = _reflection.GeneratedProtocolMessageType('CommitInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMMITINFO,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CommitInfo)
  })
_sym_db.RegisterMessage(CommitInfo)

FileInfo = _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILEINFO,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.FileInfo)
  })
_sym_db.RegisterMessage(FileInfo)

ByteRange = _reflection.GeneratedProtocolMessageType('ByteRange', (_message.Message,), {
  'DESCRIPTOR' : _BYTERANGE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ByteRange)
  })
_sym_db.RegisterMessage(ByteRange)

BlockRef = _reflection.GeneratedProtocolMessageType('BlockRef', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKREF,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.BlockRef)
  })
_sym_db.RegisterMessage(BlockRef)

ObjectInfo = _reflection.GeneratedProtocolMessageType('ObjectInfo', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTINFO,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ObjectInfo)
  })
_sym_db.RegisterMessage(ObjectInfo)

Compaction = _reflection.GeneratedProtocolMessageType('Compaction', (_message.Message,), {
  'DESCRIPTOR' : _COMPACTION,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Compaction)
  })
_sym_db.RegisterMessage(Compaction)

Shard = _reflection.GeneratedProtocolMessageType('Shard', (_message.Message,), {
  'DESCRIPTOR' : _SHARD,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Shard)
  })
_sym_db.RegisterMessage(Shard)

PathRange = _reflection.GeneratedProtocolMessageType('PathRange', (_message.Message,), {
  'DESCRIPTOR' : _PATHRANGE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.PathRange)
  })
_sym_db.RegisterMessage(PathRange)

CreateRepoRequest = _reflection.GeneratedProtocolMessageType('CreateRepoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPOREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CreateRepoRequest)
  })
_sym_db.RegisterMessage(CreateRepoRequest)

InspectRepoRequest = _reflection.GeneratedProtocolMessageType('InspectRepoRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTREPOREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.InspectRepoRequest)
  })
_sym_db.RegisterMessage(InspectRepoRequest)

ListRepoRequest = _reflection.GeneratedProtocolMessageType('ListRepoRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPOREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListRepoRequest)
  })
_sym_db.RegisterMessage(ListRepoRequest)

ListRepoResponse = _reflection.GeneratedProtocolMessageType('ListRepoResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORESPONSE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListRepoResponse)
  })
_sym_db.RegisterMessage(ListRepoResponse)

DeleteRepoRequest = _reflection.GeneratedProtocolMessageType('DeleteRepoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPOREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteRepoRequest)
  })
_sym_db.RegisterMessage(DeleteRepoRequest)

StartCommitRequest = _reflection.GeneratedProtocolMessageType('StartCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTCOMMITREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.StartCommitRequest)
  })
_sym_db.RegisterMessage(StartCommitRequest)

BuildCommitRequest = _reflection.GeneratedProtocolMessageType('BuildCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUILDCOMMITREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.BuildCommitRequest)
  })
_sym_db.RegisterMessage(BuildCommitRequest)

FinishCommitRequest = _reflection.GeneratedProtocolMessageType('FinishCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINISHCOMMITREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.FinishCommitRequest)
  })
_sym_db.RegisterMessage(FinishCommitRequest)

InspectCommitRequest = _reflection.GeneratedProtocolMessageType('InspectCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTCOMMITREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.InspectCommitRequest)
  })
_sym_db.RegisterMessage(InspectCommitRequest)

ListCommitRequest = _reflection.GeneratedProtocolMessageType('ListCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListCommitRequest)
  })
_sym_db.RegisterMessage(ListCommitRequest)

CommitInfos = _reflection.GeneratedProtocolMessageType('CommitInfos', (_message.Message,), {
  'DESCRIPTOR' : _COMMITINFOS,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CommitInfos)
  })
_sym_db.RegisterMessage(CommitInfos)

CreateBranchRequest = _reflection.GeneratedProtocolMessageType('CreateBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBRANCHREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CreateBranchRequest)
  })
_sym_db.RegisterMessage(CreateBranchRequest)

InspectBranchRequest = _reflection.GeneratedProtocolMessageType('InspectBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTBRANCHREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.InspectBranchRequest)
  })
_sym_db.RegisterMessage(InspectBranchRequest)

ListBranchRequest = _reflection.GeneratedProtocolMessageType('ListBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBRANCHREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListBranchRequest)
  })
_sym_db.RegisterMessage(ListBranchRequest)

DeleteBranchRequest = _reflection.GeneratedProtocolMessageType('DeleteBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBRANCHREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteBranchRequest)
  })
_sym_db.RegisterMessage(DeleteBranchRequest)

DeleteCommitRequest = _reflection.GeneratedProtocolMessageType('DeleteCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMMITREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteCommitRequest)
  })
_sym_db.RegisterMessage(DeleteCommitRequest)

FlushCommitRequest = _reflection.GeneratedProtocolMessageType('FlushCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _FLUSHCOMMITREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.FlushCommitRequest)
  })
_sym_db.RegisterMessage(FlushCommitRequest)

SubscribeCommitRequest = _reflection.GeneratedProtocolMessageType('SubscribeCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBECOMMITREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.SubscribeCommitRequest)
  })
_sym_db.RegisterMessage(SubscribeCommitRequest)

GetFileRequest = _reflection.GeneratedProtocolMessageType('GetFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.GetFileRequest)
  })
_sym_db.RegisterMessage(GetFileRequest)

OverwriteIndex = _reflection.GeneratedProtocolMessageType('OverwriteIndex', (_message.Message,), {
  'DESCRIPTOR' : _OVERWRITEINDEX,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.OverwriteIndex)
  })
_sym_db.RegisterMessage(OverwriteIndex)

PutFileRequest = _reflection.GeneratedProtocolMessageType('PutFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUTFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.PutFileRequest)
  })
_sym_db.RegisterMessage(PutFileRequest)

PutFileRecord = _reflection.GeneratedProtocolMessageType('PutFileRecord', (_message.Message,), {
  'DESCRIPTOR' : _PUTFILERECORD,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.PutFileRecord)
  })
_sym_db.RegisterMessage(PutFileRecord)

PutFileRecords = _reflection.GeneratedProtocolMessageType('PutFileRecords', (_message.Message,), {
  'DESCRIPTOR' : _PUTFILERECORDS,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.PutFileRecords)
  })
_sym_db.RegisterMessage(PutFileRecords)

CopyFileRequest = _reflection.GeneratedProtocolMessageType('CopyFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _COPYFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CopyFileRequest)
  })
_sym_db.RegisterMessage(CopyFileRequest)

InspectFileRequest = _reflection.GeneratedProtocolMessageType('InspectFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.InspectFileRequest)
  })
_sym_db.RegisterMessage(InspectFileRequest)

ListFileRequest = _reflection.GeneratedProtocolMessageType('ListFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListFileRequest)
  })
_sym_db.RegisterMessage(ListFileRequest)

WalkFileRequest = _reflection.GeneratedProtocolMessageType('WalkFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _WALKFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.WalkFileRequest)
  })
_sym_db.RegisterMessage(WalkFileRequest)

GlobFileRequest = _reflection.GeneratedProtocolMessageType('GlobFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GLOBFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.GlobFileRequest)
  })
_sym_db.RegisterMessage(GlobFileRequest)

FileInfos = _reflection.GeneratedProtocolMessageType('FileInfos', (_message.Message,), {
  'DESCRIPTOR' : _FILEINFOS,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.FileInfos)
  })
_sym_db.RegisterMessage(FileInfos)

DiffFileRequest = _reflection.GeneratedProtocolMessageType('DiffFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _DIFFFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DiffFileRequest)
  })
_sym_db.RegisterMessage(DiffFileRequest)

DiffFileResponse = _reflection.GeneratedProtocolMessageType('DiffFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DIFFFILERESPONSE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DiffFileResponse)
  })
_sym_db.RegisterMessage(DiffFileResponse)

DeleteFileRequest = _reflection.GeneratedProtocolMessageType('DeleteFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFILEREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteFileRequest)
  })
_sym_db.RegisterMessage(DeleteFileRequest)

FsckRequest = _reflection.GeneratedProtocolMessageType('FsckRequest', (_message.Message,), {
  'DESCRIPTOR' : _FSCKREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.FsckRequest)
  })
_sym_db.RegisterMessage(FsckRequest)

FsckResponse = _reflection.GeneratedProtocolMessageType('FsckResponse', (_message.Message,), {
  'DESCRIPTOR' : _FSCKRESPONSE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.FsckResponse)
  })
_sym_db.RegisterMessage(FsckResponse)

FileOperationRequestV2 = _reflection.GeneratedProtocolMessageType('FileOperationRequestV2', (_message.Message,), {
  'DESCRIPTOR' : _FILEOPERATIONREQUESTV2,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.FileOperationRequestV2)
  })
_sym_db.RegisterMessage(FileOperationRequestV2)

PutTarRequestV2 = _reflection.GeneratedProtocolMessageType('PutTarRequestV2', (_message.Message,), {
  'DESCRIPTOR' : _PUTTARREQUESTV2,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.PutTarRequestV2)
  })
_sym_db.RegisterMessage(PutTarRequestV2)

DeleteFilesRequestV2 = _reflection.GeneratedProtocolMessageType('DeleteFilesRequestV2', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFILESREQUESTV2,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteFilesRequestV2)
  })
_sym_db.RegisterMessage(DeleteFilesRequestV2)

GetTarRequestV2 = _reflection.GeneratedProtocolMessageType('GetTarRequestV2', (_message.Message,), {
  'DESCRIPTOR' : _GETTARREQUESTV2,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.GetTarRequestV2)
  })
_sym_db.RegisterMessage(GetTarRequestV2)

DiffFileResponseV2 = _reflection.GeneratedProtocolMessageType('DiffFileResponseV2', (_message.Message,), {
  'DESCRIPTOR' : _DIFFFILERESPONSEV2,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DiffFileResponseV2)
  })
_sym_db.RegisterMessage(DiffFileResponseV2)

CreateTmpFileSetResponse = _reflection.GeneratedProtocolMessageType('CreateTmpFileSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETMPFILESETRESPONSE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CreateTmpFileSetResponse)
  })
_sym_db.RegisterMessage(CreateTmpFileSetResponse)

RenewTmpFileSetRequest = _reflection.GeneratedProtocolMessageType('RenewTmpFileSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RENEWTMPFILESETREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.RenewTmpFileSetRequest)
  })
_sym_db.RegisterMessage(RenewTmpFileSetRequest)

ClearCommitRequestV2 = _reflection.GeneratedProtocolMessageType('ClearCommitRequestV2', (_message.Message,), {
  'DESCRIPTOR' : _CLEARCOMMITREQUESTV2,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ClearCommitRequestV2)
  })
_sym_db.RegisterMessage(ClearCommitRequestV2)

PutObjectRequest = _reflection.GeneratedProtocolMessageType('PutObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUTOBJECTREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.PutObjectRequest)
  })
_sym_db.RegisterMessage(PutObjectRequest)

CreateObjectRequest = _reflection.GeneratedProtocolMessageType('CreateObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEOBJECTREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CreateObjectRequest)
  })
_sym_db.RegisterMessage(CreateObjectRequest)

GetObjectsRequest = _reflection.GeneratedProtocolMessageType('GetObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTSREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.GetObjectsRequest)
  })
_sym_db.RegisterMessage(GetObjectsRequest)

PutBlockRequest = _reflection.GeneratedProtocolMessageType('PutBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUTBLOCKREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.PutBlockRequest)
  })
_sym_db.RegisterMessage(PutBlockRequest)

GetBlockRequest = _reflection.GeneratedProtocolMessageType('GetBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.GetBlockRequest)
  })
_sym_db.RegisterMessage(GetBlockRequest)

GetBlocksRequest = _reflection.GeneratedProtocolMessageType('GetBlocksRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.GetBlocksRequest)
  })
_sym_db.RegisterMessage(GetBlocksRequest)

ListBlockRequest = _reflection.GeneratedProtocolMessageType('ListBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBLOCKREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListBlockRequest)
  })
_sym_db.RegisterMessage(ListBlockRequest)

TagObjectRequest = _reflection.GeneratedProtocolMessageType('TagObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _TAGOBJECTREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.TagObjectRequest)
  })
_sym_db.RegisterMessage(TagObjectRequest)

ListObjectsRequest = _reflection.GeneratedProtocolMessageType('ListObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOBJECTSREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListObjectsRequest)
  })
_sym_db.RegisterMessage(ListObjectsRequest)

ListTagsRequest = _reflection.GeneratedProtocolMessageType('ListTagsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTAGSREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListTagsRequest)
  })
_sym_db.RegisterMessage(ListTagsRequest)

ListTagsResponse = _reflection.GeneratedProtocolMessageType('ListTagsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTAGSRESPONSE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ListTagsResponse)
  })
_sym_db.RegisterMessage(ListTagsResponse)

DeleteObjectsRequest = _reflection.GeneratedProtocolMessageType('DeleteObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOBJECTSREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteObjectsRequest)
  })
_sym_db.RegisterMessage(DeleteObjectsRequest)

DeleteObjectsResponse = _reflection.GeneratedProtocolMessageType('DeleteObjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOBJECTSRESPONSE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteObjectsResponse)
  })
_sym_db.RegisterMessage(DeleteObjectsResponse)

DeleteTagsRequest = _reflection.GeneratedProtocolMessageType('DeleteTagsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETAGSREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteTagsRequest)
  })
_sym_db.RegisterMessage(DeleteTagsRequest)

DeleteTagsResponse = _reflection.GeneratedProtocolMessageType('DeleteTagsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETAGSRESPONSE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteTagsResponse)
  })
_sym_db.RegisterMessage(DeleteTagsResponse)

CheckObjectRequest = _reflection.GeneratedProtocolMessageType('CheckObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKOBJECTREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CheckObjectRequest)
  })
_sym_db.RegisterMessage(CheckObjectRequest)

CheckObjectResponse = _reflection.GeneratedProtocolMessageType('CheckObjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKOBJECTRESPONSE,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.CheckObjectResponse)
  })
_sym_db.RegisterMessage(CheckObjectResponse)

Objects = _reflection.GeneratedProtocolMessageType('Objects', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTS,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.Objects)
  })
_sym_db.RegisterMessage(Objects)

PutObjDirectRequest = _reflection.GeneratedProtocolMessageType('PutObjDirectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUTOBJDIRECTREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.PutObjDirectRequest)
  })
_sym_db.RegisterMessage(PutObjDirectRequest)

GetObjDirectRequest = _reflection.GeneratedProtocolMessageType('GetObjDirectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJDIRECTREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.GetObjDirectRequest)
  })
_sym_db.RegisterMessage(GetObjDirectRequest)

DeleteObjDirectRequest = _reflection.GeneratedProtocolMessageType('DeleteObjDirectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOBJDIRECTREQUEST,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.DeleteObjDirectRequest)
  })
_sym_db.RegisterMessage(DeleteObjDirectRequest)

ObjectIndex = _reflection.GeneratedProtocolMessageType('ObjectIndex', (_message.Message,), {

  'ObjectsEntry' : _reflection.GeneratedProtocolMessageType('ObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTINDEX_OBJECTSENTRY,
    '__module__' : 'client.pfs.pfs_pb2'
    # @@protoc_insertion_point(class_scope:pfs.ObjectIndex.ObjectsEntry)
    })
  ,

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTINDEX_TAGSENTRY,
    '__module__' : 'client.pfs.pfs_pb2'
    # @@protoc_insertion_point(class_scope:pfs.ObjectIndex.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _OBJECTINDEX,
  '__module__' : 'client.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs.ObjectIndex)
  })
_sym_db.RegisterMessage(ObjectIndex)
_sym_db.RegisterMessage(ObjectIndex.ObjectsEntry)
_sym_db.RegisterMessage(ObjectIndex.TagsEntry)


DESCRIPTOR._options = None
_OBJECTINDEX_OBJECTSENTRY._options = None
_OBJECTINDEX_TAGSENTRY._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='pfs.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=7909,
  serialized_end=10165,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateRepo',
    full_name='pfs.API.CreateRepo',
    index=0,
    containing_service=None,
    input_type=_CREATEREPOREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectRepo',
    full_name='pfs.API.InspectRepo',
    index=1,
    containing_service=None,
    input_type=_INSPECTREPOREQUEST,
    output_type=_REPOINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListRepo',
    full_name='pfs.API.ListRepo',
    index=2,
    containing_service=None,
    input_type=_LISTREPOREQUEST,
    output_type=_LISTREPORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRepo',
    full_name='pfs.API.DeleteRepo',
    index=3,
    containing_service=None,
    input_type=_DELETEREPOREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StartCommit',
    full_name='pfs.API.StartCommit',
    index=4,
    containing_service=None,
    input_type=_STARTCOMMITREQUEST,
    output_type=_COMMIT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FinishCommit',
    full_name='pfs.API.FinishCommit',
    index=5,
    containing_service=None,
    input_type=_FINISHCOMMITREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectCommit',
    full_name='pfs.API.InspectCommit',
    index=6,
    containing_service=None,
    input_type=_INSPECTCOMMITREQUEST,
    output_type=_COMMITINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListCommit',
    full_name='pfs.API.ListCommit',
    index=7,
    containing_service=None,
    input_type=_LISTCOMMITREQUEST,
    output_type=_COMMITINFOS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListCommitStream',
    full_name='pfs.API.ListCommitStream',
    index=8,
    containing_service=None,
    input_type=_LISTCOMMITREQUEST,
    output_type=_COMMITINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCommit',
    full_name='pfs.API.DeleteCommit',
    index=9,
    containing_service=None,
    input_type=_DELETECOMMITREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FlushCommit',
    full_name='pfs.API.FlushCommit',
    index=10,
    containing_service=None,
    input_type=_FLUSHCOMMITREQUEST,
    output_type=_COMMITINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeCommit',
    full_name='pfs.API.SubscribeCommit',
    index=11,
    containing_service=None,
    input_type=_SUBSCRIBECOMMITREQUEST,
    output_type=_COMMITINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BuildCommit',
    full_name='pfs.API.BuildCommit',
    index=12,
    containing_service=None,
    input_type=_BUILDCOMMITREQUEST,
    output_type=_COMMIT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBranch',
    full_name='pfs.API.CreateBranch',
    index=13,
    containing_service=None,
    input_type=_CREATEBRANCHREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectBranch',
    full_name='pfs.API.InspectBranch',
    index=14,
    containing_service=None,
    input_type=_INSPECTBRANCHREQUEST,
    output_type=_BRANCHINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListBranch',
    full_name='pfs.API.ListBranch',
    index=15,
    containing_service=None,
    input_type=_LISTBRANCHREQUEST,
    output_type=_BRANCHINFOS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteBranch',
    full_name='pfs.API.DeleteBranch',
    index=16,
    containing_service=None,
    input_type=_DELETEBRANCHREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PutFile',
    full_name='pfs.API.PutFile',
    index=17,
    containing_service=None,
    input_type=_PUTFILEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CopyFile',
    full_name='pfs.API.CopyFile',
    index=18,
    containing_service=None,
    input_type=_COPYFILEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetFile',
    full_name='pfs.API.GetFile',
    index=19,
    containing_service=None,
    input_type=_GETFILEREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectFile',
    full_name='pfs.API.InspectFile',
    index=20,
    containing_service=None,
    input_type=_INSPECTFILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListFile',
    full_name='pfs.API.ListFile',
    index=21,
    containing_service=None,
    input_type=_LISTFILEREQUEST,
    output_type=_FILEINFOS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListFileStream',
    full_name='pfs.API.ListFileStream',
    index=22,
    containing_service=None,
    input_type=_LISTFILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WalkFile',
    full_name='pfs.API.WalkFile',
    index=23,
    containing_service=None,
    input_type=_WALKFILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GlobFile',
    full_name='pfs.API.GlobFile',
    index=24,
    containing_service=None,
    input_type=_GLOBFILEREQUEST,
    output_type=_FILEINFOS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GlobFileStream',
    full_name='pfs.API.GlobFileStream',
    index=25,
    containing_service=None,
    input_type=_GLOBFILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DiffFile',
    full_name='pfs.API.DiffFile',
    index=26,
    containing_service=None,
    input_type=_DIFFFILEREQUEST,
    output_type=_DIFFFILERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFile',
    full_name='pfs.API.DeleteFile',
    index=27,
    containing_service=None,
    input_type=_DELETEFILEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='pfs.API.DeleteAll',
    index=28,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Fsck',
    full_name='pfs.API.Fsck',
    index=29,
    containing_service=None,
    input_type=_FSCKREQUEST,
    output_type=_FSCKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FileOperationV2',
    full_name='pfs.API.FileOperationV2',
    index=30,
    containing_service=None,
    input_type=_FILEOPERATIONREQUESTV2,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTarV2',
    full_name='pfs.API.GetTarV2',
    index=31,
    containing_service=None,
    input_type=_GETTARREQUESTV2,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DiffFileV2',
    full_name='pfs.API.DiffFileV2',
    index=32,
    containing_service=None,
    input_type=_DIFFFILEREQUEST,
    output_type=_DIFFFILERESPONSEV2,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTmpFileSet',
    full_name='pfs.API.CreateTmpFileSet',
    index=33,
    containing_service=None,
    input_type=_FILEOPERATIONREQUESTV2,
    output_type=_CREATETMPFILESETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RenewTmpFileSet',
    full_name='pfs.API.RenewTmpFileSet',
    index=34,
    containing_service=None,
    input_type=_RENEWTMPFILESETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ClearCommitV2',
    full_name='pfs.API.ClearCommitV2',
    index=35,
    containing_service=None,
    input_type=_CLEARCOMMITREQUESTV2,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API


_OBJECTAPI = _descriptor.ServiceDescriptor(
  name='ObjectAPI',
  full_name='pfs.ObjectAPI',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=10168,
  serialized_end=11620,
  methods=[
  _descriptor.MethodDescriptor(
    name='PutObject',
    full_name='pfs.ObjectAPI.PutObject',
    index=0,
    containing_service=None,
    input_type=_PUTOBJECTREQUEST,
    output_type=_OBJECT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PutObjectSplit',
    full_name='pfs.ObjectAPI.PutObjectSplit',
    index=1,
    containing_service=None,
    input_type=_PUTOBJECTREQUEST,
    output_type=_OBJECTS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PutObjects',
    full_name='pfs.ObjectAPI.PutObjects',
    index=2,
    containing_service=None,
    input_type=_PUTOBJECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateObject',
    full_name='pfs.ObjectAPI.CreateObject',
    index=3,
    containing_service=None,
    input_type=_CREATEOBJECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetObject',
    full_name='pfs.ObjectAPI.GetObject',
    index=4,
    containing_service=None,
    input_type=_OBJECT,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetObjects',
    full_name='pfs.ObjectAPI.GetObjects',
    index=5,
    containing_service=None,
    input_type=_GETOBJECTSREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PutBlock',
    full_name='pfs.ObjectAPI.PutBlock',
    index=6,
    containing_service=None,
    input_type=_PUTBLOCKREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlock',
    full_name='pfs.ObjectAPI.GetBlock',
    index=7,
    containing_service=None,
    input_type=_GETBLOCKREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlocks',
    full_name='pfs.ObjectAPI.GetBlocks',
    index=8,
    containing_service=None,
    input_type=_GETBLOCKSREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListBlock',
    full_name='pfs.ObjectAPI.ListBlock',
    index=9,
    containing_service=None,
    input_type=_LISTBLOCKREQUEST,
    output_type=_BLOCK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='TagObject',
    full_name='pfs.ObjectAPI.TagObject',
    index=10,
    containing_service=None,
    input_type=_TAGOBJECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectObject',
    full_name='pfs.ObjectAPI.InspectObject',
    index=11,
    containing_service=None,
    input_type=_OBJECT,
    output_type=_OBJECTINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CheckObject',
    full_name='pfs.ObjectAPI.CheckObject',
    index=12,
    containing_service=None,
    input_type=_CHECKOBJECTREQUEST,
    output_type=_CHECKOBJECTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListObjects',
    full_name='pfs.ObjectAPI.ListObjects',
    index=13,
    containing_service=None,
    input_type=_LISTOBJECTSREQUEST,
    output_type=_OBJECTINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteObjects',
    full_name='pfs.ObjectAPI.DeleteObjects',
    index=14,
    containing_service=None,
    input_type=_DELETEOBJECTSREQUEST,
    output_type=_DELETEOBJECTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTag',
    full_name='pfs.ObjectAPI.GetTag',
    index=15,
    containing_service=None,
    input_type=_TAG,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InspectTag',
    full_name='pfs.ObjectAPI.InspectTag',
    index=16,
    containing_service=None,
    input_type=_TAG,
    output_type=_OBJECTINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListTags',
    full_name='pfs.ObjectAPI.ListTags',
    index=17,
    containing_service=None,
    input_type=_LISTTAGSREQUEST,
    output_type=_LISTTAGSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTags',
    full_name='pfs.ObjectAPI.DeleteTags',
    index=18,
    containing_service=None,
    input_type=_DELETETAGSREQUEST,
    output_type=_DELETETAGSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Compact',
    full_name='pfs.ObjectAPI.Compact',
    index=19,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PutObjDirect',
    full_name='pfs.ObjectAPI.PutObjDirect',
    index=20,
    containing_service=None,
    input_type=_PUTOBJDIRECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetObjDirect',
    full_name='pfs.ObjectAPI.GetObjDirect',
    index=21,
    containing_service=None,
    input_type=_GETOBJDIRECTREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteObjDirect',
    full_name='pfs.ObjectAPI.DeleteObjDirect',
    index=22,
    containing_service=None,
    input_type=_DELETEOBJDIRECTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_OBJECTAPI)

DESCRIPTOR.services_by_name['ObjectAPI'] = _OBJECTAPI

# @@protoc_insertion_point(module_scope)
